# ACT I

### PROLOGUE

**Prologue**
In Troy, there lies the scene. From isles of Greece  
The princes orgulous, their high blood chafed,  
Have to the port of Athens sent their ships,  
Fraught with the ministers and instruments  
Of cruel war: sixty and nine, that wore  
Their crownets regal, from the Athenian bay  
Put forth toward Phrygia; and their vow is made  
To ransack Troy, within whose strong immures  
The ravish'd Helen, Menelaus' queen,  
With wanton Paris sleeps; and that's the quarrel.  
To Tenedos they come;  
And the deep-drawing barks do there disgorge  
Their warlike fraughtage: now on Dardan plains  
The fresh and yet unbruised Greeks do pitch  
Their brave pavilions: Priam's six-gated city,  
Dardan, and Tymbria, Helias, Chetas, Troien,  
And Antenorides, with massy staples  
And corresponsive and fulfilling bolts,  
Sperr up the sons of Troy.  
Now expectation, tickling skittish spirits,  
On one and other side, Trojan and Greek,  
Sets all on hazard: and hither am I come  
A prologue arm'd, but not in confidence  
Of author's pen or actor's voice, but suited  
In like conditions as our argument,  
To tell you, fair beholders, that our play  
Leaps o'er the vaunt and firstlings of those broils,  
Beginning in the middle, starting thence away  
To what may be digested in a play.  
Like or find fault; do as your pleasures are:  
Now good or bad, 'tis but the chance of war.  

### SCENE I. Troy. Before Priam's palace.

_Enter TROILUS armed, and PANDARUS_

**TROILUS**  
Call here my varlet; I'll unarm again:  
Why should I war without the walls of Troy,  
That find such cruel battle here within?  
Each Trojan that is master of his heart,  
Let him to field; Troilus, alas! hath none.  

**PANDARUS**  
Will this gear ne'er be mended?  

**TROILUS**  
The Greeks are strong and skilful to their strength,  
Fierce to their skill and to their fierceness valiant;  
But I am weaker than a woman's tear,  
Tamer than sleep, fonder than ignorance,  
Less valiant than the virgin in the night  
And skilless as unpractised infancy.  

**PANDARUS**  
Well, I have told you enough of this: for my part,  
I'll not meddle nor make no further. He that will  
have a cake out of the wheat must needs tarry the grinding.  

**TROILUS**  
Have I not tarried?  

**PANDARUS**  
Ay, the grinding; but you must tarry  
the bolting.  

**TROILUS**  
Have I not tarried?  

**PANDARUS**  
Ay, the bolting, but you must tarry the leavening.  

**TROILUS**  
Still have I tarried.  

**PANDARUS**  
Ay, to the leavening; but here's yet in the word  
'hereafter' the kneading, the making of the cake, the  
heating of the oven and the baking; nay, you must  
stay the cooling too, or you may chance to burn your lips.  

**TROILUS**  
Patience herself, what goddess e'er she be,  
Doth lesser blench at sufferance than I do.  
At Priam's royal table do I sit;  
And when fair Cressid comes into my thoughts,--  
So, traitor! 'When she comes!' When is she thence?  

**PANDARUS**  
Well, she looked yesternight fairer than ever I saw  
her look, or any woman else.  

**TROILUS**  
I was about to tell thee:--when my heart,  
As wedged with a sigh, would rive in twain,  
Lest Hector or my father should perceive me,  
I have, as when the sun doth light a storm,  
Buried this sigh in wrinkle of a smile:  
But sorrow, that is couch'd in seeming gladness,  
Is like that mirth fate turns to sudden sadness.  

**PANDARUS**  
An her hair were not somewhat darker than Helen's--  
well, go to--there were no more comparison between  
the women: but, for my part, she is my kinswoman; I  
would not, as they term it, praise her: but I would  
somebody had heard her talk yesterday, as I did. I  
will not dispraise your sister Cassandra's wit, but--  

**TROILUS**  
O Pandarus! I tell thee, Pandarus,--  
When I do tell thee, there my hopes lie drown'd,  
Reply not in how many fathoms deep  
They lie indrench'd. I tell thee I am mad  
In Cressid's love: thou answer'st 'she is fair;'  
Pour'st in the open ulcer of my heart  
Her eyes, her hair, her cheek, her gait, her voice,  
Handlest in thy discourse, O, that her hand,  
In whose comparison all whites are ink,  
Writing their own reproach, to whose soft seizure  
The cygnet's down is harsh and spirit of sense  
Hard as the palm of ploughman: this thou tell'st me,  
As true thou tell'st me, when I say I love her;  
But, saying thus, instead of oil and balm,  
Thou lay'st in every gash that love hath given me  
The knife that made it.  

**PANDARUS**  
I speak no more than truth.  

**TROILUS**  
Thou dost not speak so much.  

**PANDARUS**  
Faith, I'll not meddle in't. Let her be as she is:  
if she be fair, 'tis the better for her; an she be  
not, she has the mends in her own hands.  

**TROILUS**  
Good Pandarus, how now, Pandarus!  

**PANDARUS**  
I have had my labour for my travail; ill-thought on of  
her and ill-thought on of you; gone between and  
between, but small thanks for my labour.  

**TROILUS**  
What, art thou angry, Pandarus? what, with me?  

**PANDARUS**  
Because she's kin to me, therefore she's not so fair  
as Helen: an she were not kin to me, she would be as  
fair on Friday as Helen is on Sunday. But what care  
I? I care not an she were a black-a-moor; 'tis all one to me.  

**TROILUS**  
Say I she is not fair?  

**PANDARUS**  
I do not care whether you do or no. She's a fool to  
stay behind her father; let her to the Greeks; and so  
I'll tell her the next time I see her: for my part,  
I'll meddle nor make no more i' the matter.  

**TROILUS**  
Pandarus,--  

**PANDARUS**  
Not I.  

**TROILUS**  
Sweet Pandarus,--  

**PANDARUS**  
Pray you, speak no more to me: I will leave all as I  
found it, and there an end.  

_Exit PANDARUS. An alarum_

**TROILUS**  
Peace, you ungracious clamours! peace, rude sounds!  
Fools on both sides! Helen must needs be fair,  
When with your blood you daily paint her thus.  
I cannot fight upon this argument;  
It is too starved a subject for my sword.  
But Pandarus,--O gods, how do you plague me!  
I cannot come to Cressid but by Pandar;  
And he's as tetchy to be woo'd to woo.  
As she is stubborn-chaste against all suit.  
Tell me, Apollo, for thy Daphne's love,  
What Cressid is, what Pandar, and what we?  
Her bed is India; there she lies, a pearl:  
Between our Ilium and where she resides,  
Let it be call'd the wild and wandering flood,  
Ourself the merchant, and this sailing Pandar  
Our doubtful hope, our convoy and our bark.  

_Alarum. Enter AENEAS_

**AENEAS**  
How now, Prince Troilus! wherefore not afield?  

**TROILUS**  
Because not there: this woman's answer sorts,  
For womanish it is to be from thence.  
What news, AEneas, from the field to-day?  

**AENEAS**  
That Paris is returned home and hurt.  

**TROILUS**  
By whom, AEneas?  

**AENEAS**  
Troilus, by Menelaus.  

**TROILUS**  
Let Paris bleed; 'tis but a scar to scorn;  
Paris is gored with Menelaus' horn.  

_Alarum_

**AENEAS**  
Hark, what good sport is out of town to-day!  

**TROILUS**  
Better at home, if 'would I might' were 'may.'  
But to the sport abroad: are you bound thither?  

**AENEAS**  
In all swift haste.  

**TROILUS**  
Come, go we then together.  

_Exeunt_

### SCENE II. The Same. A street.

_Enter CRESSIDA and ALEXANDER_

**CRESSIDA**  
Who were those went by?  

**ALEXANDER**  
Queen Hecuba and Helen.  

**CRESSIDA**  
And whither go they?  

**ALEXANDER**  
Up to the eastern tower,  
Whose height commands as subject all the vale,  
To see the battle. Hector, whose patience  
Is, as a virtue, fix'd, to-day was moved:  
He chid Andromache and struck his armourer,  
And, like as there were husbandry in war,  
Before the sun rose he was harness'd light,  
And to the field goes he; where every flower  
Did, as a prophet, weep what it foresaw  
In Hector's wrath.  

**CRESSIDA**  
What was his cause of anger?  

**ALEXANDER**  
The noise goes, this: there is among the Greeks  
A lord of Trojan blood, nephew to Hector;  
They call him Ajax.  

**CRESSIDA**  
Good; and what of him?  

**ALEXANDER**  
They say he is a very man per se,  
And stands alone.  

**CRESSIDA**  
So do all men, unless they are drunk, sick, or have no legs.  

**ALEXANDER**  
This man, lady, hath robbed many beasts of their  
particular additions; he is as valiant as the lion,  
churlish as the bear, slow as the elephant: a man  
into whom nature hath so crowded humours that his  
valour is crushed into folly, his folly sauced with  
discretion: there is no man hath a virtue that he  
hath not a glimpse of, nor any man an attaint but he  
carries some stain of it: he is melancholy without  
cause, and merry against the hair: he hath the  
joints of every thing, but everything so out of joint  
that he is a gouty Briareus, many hands and no use,  
or purblind Argus, all eyes and no sight.  

**CRESSIDA**  
But how should this man, that makes  
me smile, make Hector angry?  

**ALEXANDER**  
They say he yesterday coped Hector in the battle and  
struck him down, the disdain and shame whereof hath  
ever since kept Hector fasting and waking.  

**CRESSIDA**  
Who comes here?  

**ALEXANDER**  
Madam, your uncle Pandarus.  

_Enter PANDARUS_

**CRESSIDA**  
Hector's a gallant man.  

**ALEXANDER**  
As may be in the world, lady.  

**PANDARUS**  
What's that? what's that?  

**CRESSIDA**  
Good morrow, uncle Pandarus.  

**PANDARUS**  
Good morrow, cousin Cressid: what do you talk of?  
Good morrow, Alexander. How do you, cousin? When  
were you at Ilium?  

**CRESSIDA**  
This morning, uncle.  

**PANDARUS**  
What were you talking of when I came? Was Hector  
armed and gone ere ye came to Ilium? Helen was not  
up, was she?  

**CRESSIDA**  
Hector was gone, but Helen was not up.  

**PANDARUS**  
Even so: Hector was stirring early.  

**CRESSIDA**  
That were we talking of, and of his anger.  

**PANDARUS**  
Was he angry?  

**CRESSIDA**  
So he says here.  

**PANDARUS**  
True, he was so: I know the cause too: he'll lay  
about him to-day, I can tell them that: and there's  
Troilus will not come far behind him: let them take  
heed of Troilus, I can tell them that too.  

**CRESSIDA**  
What, is he angry too?  

**PANDARUS**  
Who, Troilus? Troilus is the better man of the two.  

**CRESSIDA**  
O Jupiter! there's no comparison.  

**PANDARUS**  
What, not between Troilus and Hector? Do you know a  
man if you see him?  

**CRESSIDA**  
Ay, if I ever saw him before and knew him.  

**PANDARUS**  
Well, I say Troilus is Troilus.  

**CRESSIDA**  
Then you say as I say; for, I am sure, he is not Hector.  

**PANDARUS**  
No, nor Hector is not Troilus in some degrees.  

**CRESSIDA**  
'Tis just to each of them; he is himself.  

**PANDARUS**  
Himself! Alas, poor Troilus! I would he were.  

**CRESSIDA**  
So he is.  

**PANDARUS**  
Condition, I had gone barefoot to India.  

**CRESSIDA**  
He is not Hector.  

**PANDARUS**  
Himself! no, he's not himself: would a' were  
himself! Well, the gods are above; time must friend  
or end: well, Troilus, well: I would my heart were  
in her body. No, Hector is not a better man than Troilus.  

**CRESSIDA**  
Excuse me.  

**PANDARUS**  
He is elder.  

**CRESSIDA**  
Pardon me, pardon me.  

**PANDARUS**  
Th' other's not come to't; you shall tell me another  
tale, when th' other's come to't. Hector shall not  
have his wit this year.  

**CRESSIDA**  
He shall not need it, if he have his own.  

**PANDARUS**  
Nor his qualities.  

**CRESSIDA**  
No matter.  

**PANDARUS**  
Nor his beauty.  

**CRESSIDA**  
'Twould not become him; his own's better.  

**PANDARUS**  
You have no judgment, niece: Helen  
herself swore th' other day, that Troilus, for  
a brown favour--for so 'tis, I must confess,--  
not brown neither,--  

**CRESSIDA**  
No, but brown.  

**PANDARUS**  
'Faith, to say truth, brown and not brown.  

**CRESSIDA**  
To say the truth, true and not true.  

**PANDARUS**  
She praised his complexion above Paris.  

**CRESSIDA**  
Why, Paris hath colour enough.  

**PANDARUS**  
So he has.  

**CRESSIDA**  
Then Troilus should have too much: if she praised  
him above, his complexion is higher than his; he  
having colour enough, and the other higher, is too  
flaming a praise for a good complexion. I had as  
lief Helen's golden tongue had commended Troilus for  
a copper nose.  

**PANDARUS**  
I swear to you. I think Helen loves him better than Paris.  

**CRESSIDA**  
Then she's a merry Greek indeed.  

**PANDARUS**  
Nay, I am sure she does. She came to him th' other  
day into the compassed window,--and, you know, he  
has not past three or four hairs on his chin,--  

**CRESSIDA**  
Indeed, a tapster's arithmetic may soon bring his  
particulars therein to a total.  

**PANDARUS**  
Why, he is very young: and yet will he, within  
three pound, lift as much as his brother Hector.  

**CRESSIDA**  
Is he so young a man and so old a lifter?  

**PANDARUS**  
But to prove to you that Helen loves him: she came  
and puts me her white hand to his cloven chin--  

**CRESSIDA**  
Juno have mercy! how came it cloven?  

**PANDARUS**  
Why, you know 'tis dimpled: I think his smiling  
becomes him better than any man in all Phrygia.  

**CRESSIDA**  
O, he smiles valiantly.  

**PANDARUS**  
Does he not?  

**CRESSIDA**  
O yes, an 'twere a cloud in autumn.  

**PANDARUS**  
Why, go to, then: but to prove to you that Helen  
loves Troilus,--  

**CRESSIDA**  
Troilus will stand to the proof, if you'll  
prove it so.  

**PANDARUS**  
Troilus! why, he esteems her no more than I esteem  
an addle egg.  

**CRESSIDA**  
If you love an addle egg as well as you love an idle  
head, you would eat chickens i' the shell.  

**PANDARUS**  
I cannot choose but laugh, to think how she tickled  
his chin: indeed, she has a marvellous white hand, I  
must needs confess,--  

**CRESSIDA**  
Without the rack.  

**PANDARUS**  
And she takes upon her to spy a white hair on his chin.  

**CRESSIDA**  
Alas, poor chin! many a wart is richer.  

**PANDARUS**  
But there was such laughing! Queen Hecuba laughed  
that her eyes ran o'er.  

**CRESSIDA**  
With mill-stones.  

**PANDARUS**  
And Cassandra laughed.  

**CRESSIDA**  
But there was more temperate fire under the pot of  
her eyes: did her eyes run o'er too?  

**PANDARUS**  
And Hector laughed.  

**CRESSIDA**  
At what was all this laughing?  

**PANDARUS**  
Marry, at the white hair that Helen spied on Troilus' chin.  

**CRESSIDA**  
An't had been a green hair, I should have laughed  
too.  

**PANDARUS**  
They laughed not so much at the hair as at his pretty answer.  

**CRESSIDA**  
What was his answer?  

**PANDARUS**  
Quoth she, 'Here's but two and fifty hairs on your  
chin, and one of them is white.  

**CRESSIDA**  
This is her question.  

**PANDARUS**  
That's true; make no question of that. 'Two and  
fifty hairs' quoth he, 'and one white: that white  
hair is my father, and all the rest are his sons.'  
'Jupiter!' quoth she, 'which of these hairs is Paris,  
my husband? 'The forked one,' quoth he, 'pluck't  
out, and give it him.' But there was such laughing!  
and Helen so blushed, an Paris so chafed, and all the  
rest so laughed, that it passed.  

**CRESSIDA**  
So let it now; for it has been while going by.  

**PANDARUS**  
Well, cousin. I told you a thing yesterday; think on't.  

**CRESSIDA**  
So I do.  

**PANDARUS**  
I'll be sworn 'tis true; he will weep you, an 'twere  
a man born in April.  

**CRESSIDA**  
And I'll spring up in his tears, an 'twere a nettle  
against May.  

_A retreat sounded_

**PANDARUS**  
Hark! they are coming from the field: shall we  
stand up here, and see them as they pass toward  
Ilium? good niece, do, sweet niece Cressida.  

**CRESSIDA**  
At your pleasure.  

**PANDARUS**  
Here, here, here's an excellent place; here we may  
see most bravely: I'll tell you them all by their  
names as they pass by; but mark Troilus above the rest.  

**CRESSIDA**  
Speak not so loud.  

_AENEAS passes_

**PANDARUS**  
That's AEneas: is not that a brave man? he's one of  
the flowers of Troy, I can tell you: but mark  
Troilus; you shall see anon.  

_ANTENOR passes_

**CRESSIDA**  
Who's that?  

**PANDARUS**  
That's Antenor: he has a shrewd wit, I can tell you;  
and he's a man good enough, he's one o' the soundest  
judgments in whosoever, and a proper man of person.  
When comes Troilus? I'll show you Troilus anon: if  
he see me, you shall see him nod at me.  

**CRESSIDA**  
Will he give you the nod?  

**PANDARUS**  
You shall see.  

**CRESSIDA**  
If he do, the rich shall have more.  

_HECTOR passes_

**PANDARUS**  
That's Hector, that, that, look you, that; there's a  
fellow! Go thy way, Hector! There's a brave man,  
niece. O brave Hector! Look how he looks! there's  
a countenance! is't not a brave man?  

**CRESSIDA**  
O, a brave man!  

**PANDARUS**  
Is a' not? it does a man's heart good. Look you  
what hacks are on his helmet! look you yonder, do  
you see? look you there: there's no jesting;  
there's laying on, take't off who will, as they say:  
there be hacks!  

**CRESSIDA**  
Be those with swords?  

**PANDARUS**  
Swords! any thing, he cares not; an the devil come  
to him, it's all one: by God's lid, it does one's  
heart good. Yonder comes Paris, yonder comes Paris.  

_PARIS passes_

Look ye yonder, niece; is't not a gallant man too,  
is't not? Why, this is brave now. Who said he came  
hurt home to-day? he's not hurt: why, this will do  
Helen's heart good now, ha! Would I could see  
Troilus now! You shall see Troilus anon.  

_HELENUS passes_

**CRESSIDA**  
Who's that?  

**PANDARUS**  
That's Helenus. I marvel where Troilus is. That's  
Helenus. I think he went not forth to-day. That's Helenus.  

**CRESSIDA**  
Can Helenus fight, uncle?  

**PANDARUS**  
Helenus? no. Yes, he'll fight indifferent well. I  
marvel where Troilus is. Hark! do you not hear the  
people cry 'Troilus'? Helenus is a priest.  

**CRESSIDA**  
What sneaking fellow comes yonder?  

_TROILUS passes_

**PANDARUS**  
Where? yonder? that's Deiphobus. 'Tis Troilus!  
there's a man, niece! Hem! Brave Troilus! the  
prince of chivalry!  

**CRESSIDA**  
Peace, for shame, peace!  

**PANDARUS**  
Mark him; note him. O brave Troilus! Look well upon  
him, niece: look you how his sword is bloodied, and  
his helm more hacked than Hector's, and how he looks,  
and how he goes! O admirable youth! he ne'er saw  
three and twenty. Go thy way, Troilus, go thy way!  
Had I a sister were a grace, or a daughter a goddess,  
he should take his choice. O admirable man! Paris?  
Paris is dirt to him; and, I warrant, Helen, to  
change, would give an eye to boot.  

**CRESSIDA**  
Here come more.  

_Forces pass_

**PANDARUS**  
Asses, fools, dolts! chaff and bran, chaff and bran!  
porridge after meat! I could live and die i' the  
eyes of Troilus. Ne'er look, ne'er look: the eagles  
are gone: crows and daws, crows and daws! I had  
rather be such a man as Troilus than Agamemnon and  
all Greece.  

**CRESSIDA**  
There is among the Greeks Achilles, a better man than Troilus.  

**PANDARUS**  
Achilles! a drayman, a porter, a very camel.  

**CRESSIDA**  
Well, well.  

**PANDARUS**  
'Well, well!' why, have you any discretion? have  
you any eyes? Do you know what a man is? Is not  
birth, beauty, good shape, discourse, manhood,  
learning, gentleness, virtue, youth, liberality,  
and such like, the spice and salt that season a man?  

**CRESSIDA**  
Ay, a minced man: and then to be baked with no date  
in the pie, for then the man's date's out.  

**PANDARUS**  
You are such a woman! one knows not at what ward you  
lie.  

**CRESSIDA**  
Upon my back, to defend my belly; upon my wit, to  
defend my wiles; upon my secrecy, to defend mine  
honesty; my mask, to defend my beauty; and you, to  
defend all these: and at all these wards I lie, at a  
thousand watches.  

**PANDARUS**  
Say one of your watches.  

**CRESSIDA**  
Nay, I'll watch you for that; and that's one of the  
chiefest of them too: if I cannot ward what I would  
not have hit, I can watch you for telling how I took  
the blow; unless it swell past hiding, and then it's  
past watching.  

**PANDARUS**  
You are such another!  

_Enter Troilus 's Boy_

**Boy**  
Sir, my lord would instantly speak with you.  

**PANDARUS**  
Where?  

**Boy**  
At your own house; there he unarms him.  

**PANDARUS**  
Good boy, tell him I come.  

_Exit boy_

I doubt he be hurt. Fare ye well, good niece.  

**CRESSIDA**  
Adieu, uncle.  

**PANDARUS**  
I'll be with you, niece, by and by.  

**CRESSIDA**  
To bring, uncle?  

**PANDARUS**  
Ay, a token from Troilus.  

**CRESSIDA**  
By the same token, you are a bawd.  

_Exit PANDARUS_

Words, vows, gifts, tears, and love's full sacrifice,  
He offers in another's enterprise;  
But more in Troilus thousand fold I see  
Than in the glass of Pandar's praise may be;  
Yet hold I off. Women are angels, wooing:  
Things won are done; joy's soul lies in the doing.  
That she beloved knows nought that knows not this:  
Men prize the thing ungain'd more than it is:  
That she was never yet that ever knew  
Love got so sweet as when desire did sue.  
Therefore this maxim out of love I teach:  
Achievement is command; ungain'd, beseech:  
Then though my heart's content firm love doth bear,  
Nothing of that shall from mine eyes appear.  

_Exeunt_

### SCENE III. The Grecian camp. Before Agamemnon's tent.

_Sennet. Enter AGAMEMNON, NESTOR, ULYSSES, MENELAUS, and others_

**AGAMEMNON**  
Princes,  
What grief hath set the jaundice on your cheeks?  
The ample proposition that hope makes  
In all designs begun on earth below  
Fails in the promised largeness: cheques and disasters  
Grow in the veins of actions highest rear'd,  
As knots, by the conflux of meeting sap,  
Infect the sound pine and divert his grain  
Tortive and errant from his course of growth.  
Nor, princes, is it matter new to us  
That we come short of our suppose so far  
That after seven years' siege yet Troy walls stand;  
Sith every action that hath gone before,  
Whereof we have record, trial did draw  
Bias and thwart, not answering the aim,  
And that unbodied figure of the thought  
That gave't surmised shape. Why then, you princes,  
Do you with cheeks abash'd behold our works,  
And call them shames? which are indeed nought else  
But the protractive trials of great Jove  
To find persistive constancy in men:  
The fineness of which metal is not found  
In fortune's love; for then the bold and coward,  
The wise and fool, the artist and unread,  
The hard and soft seem all affined and kin:  
But, in the wind and tempest of her frown,  
Distinction, with a broad and powerful fan,  
Puffing at all, winnows the light away;  
And what hath mass or matter, by itself  
Lies rich in virtue and unmingled.  

**NESTOR**  
With due observance of thy godlike seat,  
Great Agamemnon, Nestor shall apply  
Thy latest words. In the reproof of chance  
Lies the true proof of men: the sea being smooth,  
How many shallow bauble boats dare sail  
Upon her patient breast, making their way  
With those of nobler bulk!  
But let the ruffian Boreas once enrage  
The gentle Thetis, and anon behold  
The strong-ribb'd bark through liquid mountains cut,  
Bounding between the two moist elements,  
Like Perseus' horse: where's then the saucy boat  
Whose weak untimber'd sides but even now  
Co-rivall'd greatness? Either to harbour fled,  
Or made a toast for Neptune. Even so  
Doth valour's show and valour's worth divide  
In storms of fortune; for in her ray and brightness  
The herd hath more annoyance by the breeze  
Than by the tiger; but when the splitting wind  
Makes flexible the knees of knotted oaks,  
And flies fled under shade, why, then the thing of courage  
As roused with rage with rage doth sympathize,  
And with an accent tuned in selfsame key  
Retorts to chiding fortune.  

**ULYSSES**  
Agamemnon,  
Thou great commander, nerve and bone of Greece,  
Heart of our numbers, soul and only spirit.  
In whom the tempers and the minds of all  
Should be shut up, hear what Ulysses speaks.  
Besides the applause and approbation To which,  

_[To AGAMEMNON]_  
most mighty for thy place and sway,  

_[To NESTOR]_  
And thou most reverend for thy stretch'd-out life  
I give to both your speeches, which were such  
As Agamemnon and the hand of Greece  
Should hold up high in brass, and such again  
As venerable Nestor, hatch'd in silver,  
Should with a bond of air, strong as the axle-tree  
On which heaven rides, knit all the Greekish ears  
To his experienced tongue, yet let it please both,  
Thou great, and wise, to hear Ulysses speak.  

**AGAMEMNON**  
Speak, prince of Ithaca; and be't of less expect  
That matter needless, of importless burden,  
Divide thy lips, than we are confident,  
When rank Thersites opes his mastic jaws,  
We shall hear music, wit and oracle.  

**ULYSSES**  
Troy, yet upon his basis, had been down,  
And the great Hector's sword had lack'd a master,  
But for these instances.  
The specialty of rule hath been neglected:  
And, look, how many Grecian tents do stand  
Hollow upon this plain, so many hollow factions.  
When that the general is not like the hive  
To whom the foragers shall all repair,  
What honey is expected? Degree being vizarded,  
The unworthiest shows as fairly in the mask.  
The heavens themselves, the planets and this centre  
Observe degree, priority and place,  
Insisture, course, proportion, season, form,  
Office and custom, in all line of order;  
And therefore is the glorious planet Sol  
In noble eminence enthroned and sphered  
Amidst the other; whose medicinable eye  
Corrects the ill aspects of planets evil,  
And posts, like the commandment of a king,  
Sans cheque to good and bad: but when the planets  
In evil mixture to disorder wander,  
What plagues and what portents! what mutiny!  
What raging of the sea! shaking of earth!  
Commotion in the winds! frights, changes, horrors,  
Divert and crack, rend and deracinate  
The unity and married calm of states  
Quite from their fixure! O, when degree is shaked,  
Which is the ladder to all high designs,  
Then enterprise is sick! How could communities,  
Degrees in schools and brotherhoods in cities,  
Peaceful commerce from dividable shores,  
The primogenitive and due of birth,  
Prerogative of age, crowns, sceptres, laurels,  
But by degree, stand in authentic place?  
Take but degree away, untune that string,  
And, hark, what discord follows! each thing meets  
In mere oppugnancy: the bounded waters  
Should lift their bosoms higher than the shores  
And make a sop of all this solid globe:  
Strength should be lord of imbecility,  
And the rude son should strike his father dead:  
Force should be right; or rather, right and wrong,  
Between whose endless jar justice resides,  
Should lose their names, and so should justice too.  
Then every thing includes itself in power,  
Power into will, will into appetite;  
And appetite, an universal wolf,  
So doubly seconded with will and power,  
Must make perforce an universal prey,  
And last eat up himself. Great Agamemnon,  
This chaos, when degree is suffocate,  
Follows the choking.  
And this neglection of degree it is  
That by a pace goes backward, with a purpose  
It hath to climb. The general's disdain'd  
By him one step below, he by the next,  
That next by him beneath; so every step,  
Exampled by the first pace that is sick  
Of his superior, grows to an envious fever  
Of pale and bloodless emulation:  
And 'tis this fever that keeps Troy on foot,  
Not her own sinews. To end a tale of length,  
Troy in our weakness stands, not in her strength.  

**NESTOR**  
Most wisely hath Ulysses here discover'd  
The fever whereof all our power is sick.  

**AGAMEMNON**  
The nature of the sickness found, Ulysses,  
What is the remedy?  

**ULYSSES**  
The great Achilles, whom opinion crowns  
The sinew and the forehand of our host,  
Having his ear full of his airy fame,  
Grows dainty of his worth, and in his tent  
Lies mocking our designs: with him Patroclus  
Upon a lazy bed the livelong day  
Breaks scurril jests;  
And with ridiculous and awkward action,  
Which, slanderer, he imitation calls,  
He pageants us. Sometime, great Agamemnon,  
Thy topless deputation he puts on,  
And, like a strutting player, whose conceit  
Lies in his hamstring, and doth think it rich  
To hear the wooden dialogue and sound  
'Twixt his stretch'd footing and the scaffoldage,--  
Such to-be-pitied and o'er-wrested seeming  
He acts thy greatness in: and when he speaks,  
'Tis like a chime a-mending; with terms unsquared,  
Which, from the tongue of roaring Typhon dropp'd  
Would seem hyperboles. At this fusty stuff  
The large Achilles, on his press'd bed lolling,  
From his deep chest laughs out a loud applause;  
Cries 'Excellent! 'tis Agamemnon just.  
Now play me Nestor; hem, and stroke thy beard,  
As he being drest to some oration.'  
That's done, as near as the extremest ends  
Of parallels, as like as Vulcan and his wife:  
Yet god Achilles still cries 'Excellent!  
'Tis Nestor right. Now play him me, Patroclus,  
Arming to answer in a night alarm.'  
And then, forsooth, the faint defects of age  
Must be the scene of mirth; to cough and spit,  
And, with a palsy-fumbling on his gorget,  
Shake in and out the rivet: and at this sport  
Sir Valour dies; cries 'O, enough, Patroclus;  
Or give me ribs of steel! I shall split all  
In pleasure of my spleen.' And in this fashion,  
All our abilities, gifts, natures, shapes,  
Severals and generals of grace exact,  
Achievements, plots, orders, preventions,  
Excitements to the field, or speech for truce,  
Success or loss, what is or is not, serves  
As stuff for these two to make paradoxes.  

**NESTOR**  
And in the imitation of these twain--  
Who, as Ulysses says, opinion crowns  
With an imperial voice--many are infect.  
Ajax is grown self-will'd, and bears his head  
In such a rein, in full as proud a place  
As broad Achilles; keeps his tent like him;  
Makes factious feasts; rails on our state of war,  
Bold as an oracle, and sets Thersites,  
A slave whose gall coins slanders like a mint,  
To match us in comparisons with dirt,  
To weaken and discredit our exposure,  
How rank soever rounded in with danger.  

**ULYSSES**  
They tax our policy, and call it cowardice,  
Count wisdom as no member of the war,  
Forestall prescience, and esteem no act  
But that of hand: the still and mental parts,  
That do contrive how many hands shall strike,  
When fitness calls them on, and know by measure  
Of their observant toil the enemies' weight,--  
Why, this hath not a finger's dignity:  
They call this bed-work, mappery, closet-war;  
So that the ram that batters down the wall,  
For the great swing and rudeness of his poise,  
They place before his hand that made the engine,  
Or those that with the fineness of their souls  
By reason guide his execution.  

**NESTOR**  
Let this be granted, and Achilles' horse  
Makes many Thetis' sons.  

_A tucket_

**AGAMEMNON**  
What trumpet? look, Menelaus.  

**MENELAUS**  
From Troy.  

_Enter AENEAS_

**AGAMEMNON**  
What would you 'fore our tent?  

**AENEAS**  
Is this great Agamemnon's tent, I pray you?  

**AGAMEMNON**  
Even this.  

**AENEAS**  
May one, that is a herald and a prince,  
Do a fair message to his kingly ears?  

**AGAMEMNON**  
With surety stronger than Achilles' arm  
'Fore all the Greekish heads, which with one voice  
Call Agamemnon head and general.  

**AENEAS**  
Fair leave and large security. How may  
A stranger to those most imperial looks  
Know them from eyes of other mortals?  

**AGAMEMNON**  
How!  

**AENEAS**  
Ay;  
I ask, that I might waken reverence,  
And bid the cheek be ready with a blush  
Modest as morning when she coldly eyes  
The youthful Phoebus:  
Which is that god in office, guiding men?  
Which is the high and mighty Agamemnon?  

**AGAMEMNON**  
This Trojan scorns us; or the men of Troy  
Are ceremonious courtiers.  

**AENEAS**  
Courtiers as free, as debonair, unarm'd,  
As bending angels; that's their fame in peace:  
But when they would seem soldiers, they have galls,  
Good arms, strong joints, true swords; and,  
Jove's accord,  
Nothing so full of heart. But peace, AEneas,  
Peace, Trojan; lay thy finger on thy lips!  
The worthiness of praise distains his worth,  
If that the praised himself bring the praise forth:  
But what the repining enemy commends,  
That breath fame blows; that praise, sole sure,  
transcends.  

**AGAMEMNON**  
Sir, you of Troy, call you yourself AEneas?  

**AENEAS**  
Ay, Greek, that is my name.  

**AGAMEMNON**  
What's your affair I pray you?  

**AENEAS**  
Sir, pardon; 'tis for Agamemnon's ears.  

**AGAMEMNON**  
He hears naught privately that comes from Troy.  

**AENEAS**  
Nor I from Troy come not to whisper him:  
I bring a trumpet to awake his ear,  
To set his sense on the attentive bent,  
And then to speak.  

**AGAMEMNON**  
Speak frankly as the wind;  
It is not Agamemnon's sleeping hour:  
That thou shalt know. Trojan, he is awake,  
He tells thee so himself.  

**AENEAS**  
Trumpet, blow loud,  
Send thy brass voice through all these lazy tents;  
And every Greek of mettle, let him know,  
What Troy means fairly shall be spoke aloud.  

_Trumpet sounds_

We have, great Agamemnon, here in Troy  
A prince call'd Hector,--Priam is his father,--  
Who in this dull and long-continued truce  
Is rusty grown: he bade me take a trumpet,  
And to this purpose speak. Kings, princes, lords!  
If there be one among the fair'st of Greece  
That holds his honour higher than his ease,  
That seeks his praise more than he fears his peril,  
That knows his valour, and knows not his fear,  
That loves his mistress more than in confession,  
With truant vows to her own lips he loves,  
And dare avow her beauty and her worth  
In other arms than hers,--to him this challenge.  
Hector, in view of Trojans and of Greeks,  
Shall make it good, or do his best to do it,  
He hath a lady, wiser, fairer, truer,  
Than ever Greek did compass in his arms,  
And will to-morrow with his trumpet call  
Midway between your tents and walls of Troy,  
To rouse a Grecian that is true in love:  
If any come, Hector shall honour him;  
If none, he'll say in Troy when he retires,  
The Grecian dames are sunburnt and not worth  
The splinter of a lance. Even so much.  

**AGAMEMNON**  
This shall be told our lovers, Lord AEneas;  
If none of them have soul in such a kind,  
We left them all at home: but we are soldiers;  
And may that soldier a mere recreant prove,  
That means not, hath not, or is not in love!  
If then one is, or hath, or means to be,  
That one meets Hector; if none else, I am he.  

**NESTOR**  
Tell him of Nestor, one that was a man  
When Hector's grandsire suck'd: he is old now;  
But if there be not in our Grecian host  
One noble man that hath one spark of fire,  
To answer for his love, tell him from me  
I'll hide my silver beard in a gold beaver  
And in my vantbrace put this wither'd brawn,  
And meeting him will tell him that my lady  
Was fairer than his grandam and as chaste  
As may be in the world: his youth in flood,  
I'll prove this truth with my three drops of blood.  

**AENEAS**  
Now heavens forbid such scarcity of youth!  

**ULYSSES**  
Amen.  

**AGAMEMNON**  
Fair Lord AEneas, let me touch your hand;  
To our pavilion shall I lead you, sir.  
Achilles shall have word of this intent;  
So shall each lord of Greece, from tent to tent:  
Yourself shall feast with us before you go  
And find the welcome of a noble foe.  

_Exeunt all but ULYSSES and NESTOR_

**ULYSSES**  
Nestor!  

**NESTOR**  
What says Ulysses?  

**ULYSSES**  
I have a young conception in my brain;  
Be you my time to bring it to some shape.  

**NESTOR**  
What is't?  

**ULYSSES**  
This 'tis:  
Blunt wedges rive hard knots: the seeded pride  
That hath to this maturity blown up  
In rank Achilles must or now be cropp'd,  
Or, shedding, breed a nursery of like evil,  
To overbulk us all.  

**NESTOR**  
Well, and how?  

**ULYSSES**  
This challenge that the gallant Hector sends,  
However it is spread in general name,  
Relates in purpose only to Achilles.  

**NESTOR**  
The purpose is perspicuous even as substance,  
Whose grossness little characters sum up:  
And, in the publication, make no strain,  
But that Achilles, were his brain as barren  
As banks of Libya,--though, Apollo knows,  
'Tis dry enough,--will, with great speed of judgment,  
Ay, with celerity, find Hector's purpose  
Pointing on him.  

**ULYSSES**  
And wake him to the answer, think you?  

**NESTOR**  
Yes, 'tis most meet: whom may you else oppose,  
That can from Hector bring his honour off,  
If not Achilles? Though't be a sportful combat,  
Yet in the trial much opinion dwells;  
For here the Trojans taste our dear'st repute  
With their finest palate: and trust to me, Ulysses,  
Our imputation shall be oddly poised  
In this wild action; for the success,  
Although particular, shall give a scantling  
Of good or bad unto the general;  
And in such indexes, although small pricks  
To their subsequent volumes, there is seen  
The baby figure of the giant mass  
Of things to come at large. It is supposed  
He that meets Hector issues from our choice  
And choice, being mutual act of all our souls,  
Makes merit her election, and doth boil,  
As 'twere from us all, a man distill'd  
Out of our virtues; who miscarrying,  
What heart receives from hence the conquering part,  
To steel a strong opinion to themselves?  
Which entertain'd, limbs are his instruments,  
In no less working than are swords and bows  
Directive by the limbs.  

**ULYSSES**  
Give pardon to my speech:  
Therefore 'tis meet Achilles meet not Hector.  
Let us, like merchants, show our foulest wares,  
And think, perchance, they'll sell; if not,  
The lustre of the better yet to show,  
Shall show the better. Do not consent  
That ever Hector and Achilles meet;  
For both our honour and our shame in this  
Are dogg'd with two strange followers.  

**NESTOR**  
I see them not with my old eyes: what are they?  

**ULYSSES**  
What glory our Achilles shares from Hector,  
Were he not proud, we all should share with him:  
But he already is too insolent;  
A nd we were better parch in Afric sun  
Than in the pride and salt scorn of his eyes,  
Should he 'scape Hector fair: if he were foil'd,  
Why then, we did our main opinion crush  
In taint of our best man. No, make a lottery;  
And, by device, let blockish Ajax draw  
The sort to fight with Hector: among ourselves  
Give him allowance for the better man;  
For that will physic the great Myrmidon  
Who broils in loud applause, and make him fall  
His crest that prouder than blue Iris bends.  
If the dull brainless Ajax come safe off,  
We'll dress him up in voices: if he fail,  
Yet go we under our opinion still  
That we have better men. But, hit or miss,  
Our project's life this shape of sense assumes:  
Ajax employ'd plucks down Achilles' plumes.  

**NESTOR**  
Ulysses,  
Now I begin to relish thy advice;  
And I will give a taste of it forthwith  
To Agamemnon: go we to him straight.  
Two curs shall tame each other: pride alone  
Must tarre the mastiffs on, as 'twere their bone.  

_Exeunt_

# ACT II

### SCENE I. A part of the Grecian camp.

_Enter AJAX and THERSITES_

**AJAX**  
Thersites!  

**THERSITES**  
Agamemnon, how if he had boils? full, all over,  
generally?  

**AJAX**  
Thersites!  

**THERSITES**  
And those boils did run? say so: did not the  
general run then? were not that a botchy core?  

**AJAX**  
Dog!  

**THERSITES**  
Then would come some matter from him; I see none now.  

**AJAX**  
Thou bitch-wolf's son, canst thou not hear?  

_Beating him_

Feel, then.  

**THERSITES**  
The plague of Greece upon thee, thou mongrel  
beef-witted lord!  

**AJAX**  
Speak then, thou vinewedst leaven, speak: I will  
beat thee into handsomeness.  

**THERSITES**  
I shall sooner rail thee into wit and holiness: but,  
I think, thy horse will sooner con an oration than  
thou learn a prayer without book. Thou canst strike,  
canst thou? a red murrain o' thy jade's tricks!  

**AJAX**  
Toadstool, learn me the proclamation.  

**THERSITES**  
Dost thou think I have no sense, thou strikest me thus?  

**AJAX**  
The proclamation!  

**THERSITES**  
Thou art proclaimed a fool, I think.  

**AJAX**  
Do not, porpentine, do not: my fingers itch.  

**THERSITES**  
I would thou didst itch from head to foot and I had  
the scratching of thee; I would make thee the  
loathsomest scab in Greece. When thou art forth in  
the incursions, thou strikest as slow as another.  

**AJAX**  
I say, the proclamation!  

**THERSITES**  
Thou grumblest and railest every hour on Achilles,  
and thou art as full of envy at his greatness as  
Cerberus is at Proserpine's beauty, ay, that thou  
barkest at him.  

**AJAX**  
Mistress Thersites!  

**THERSITES**  
Thou shouldest strike him.  

**AJAX**  
Cobloaf!  

**THERSITES**  
He would pun thee into shivers with his fist, as a  
sailor breaks a biscuit.  

**AJAX**  
_[Beating him]_  
You whoreson cur!  

**THERSITES**  
Do, do.  

**AJAX**  
Thou stool for a witch!  

**THERSITES**  
Ay, do, do; thou sodden-witted lord! thou hast no  
more brain than I have in mine elbows; an assinego  
may tutor thee: thou scurvy-valiant ass! thou art  
here but to thrash Trojans; and thou art bought and  
sold among those of any wit, like a barbarian slave.  
If thou use to beat me, I will begin at thy heel, and  
tell what thou art by inches, thou thing of no  
bowels, thou!  

**AJAX**  
You dog!  

**THERSITES**  
You scurvy lord!  

**AJAX**  
_[Beating him]_  
You cur!  

**THERSITES**  
Mars his idiot! do, rudeness; do, camel; do, do.  

_Enter ACHILLES and PATROCLUS_

**ACHILLES**  
Why, how now, Ajax! wherefore do you thus? How now,  
Thersites! what's the matter, man?  

**THERSITES**  
You see him there, do you?  

**ACHILLES**  
Ay; what's the matter?  

**THERSITES**  
Nay, look upon him.  

**ACHILLES**  
So I do: what's the matter?  

**THERSITES**  
Nay, but regard him well.  

**ACHILLES**  
'Well!' why, I do so.  

**THERSITES**  
But yet you look not well upon him; for whosoever you  
take him to be, he is Ajax.  

**ACHILLES**  
I know that, fool.  

**THERSITES**  
Ay, but that fool knows not himself.  

**AJAX**  
Therefore I beat thee.  

**THERSITES**  
Lo, lo, lo, lo, what modicums of wit he utters! his  
evasions have ears thus long. I have bobbed his  
brain more than he has beat my bones: I will buy  
nine sparrows for a penny, and his pia mater is not  
worth the nineth part of a sparrow. This lord,  
Achilles, Ajax, who wears his wit in his belly and  
his guts in his head, I'll tell you what I say of  
him.  

**ACHILLES**  
What?  

**THERSITES**  
I say, this Ajax--  

_Ajax offers to beat him_

**ACHILLES**  
Nay, good Ajax.  

**THERSITES**  
Has not so much wit--  

**ACHILLES**  
Nay, I must hold you.  

**THERSITES**  
As will stop the eye of Helen's needle, for whom he  
comes to fight.  

**ACHILLES**  
Peace, fool!  

**THERSITES**  
I would have peace and quietness, but the fool will  
not: he there: that he: look you there.  

**AJAX**  
O thou damned cur! I shall--  

**ACHILLES**  
Will you set your wit to a fool's?  

**THERSITES**  
No, I warrant you; for a fools will shame it.  

**PATROCLUS**  
Good words, Thersites.  

**ACHILLES**  
What's the quarrel?  

**AJAX**  
I bade the vile owl go learn me the tenor of the  
proclamation, and he rails upon me.  

**THERSITES**  
I serve thee not.  

**AJAX**  
Well, go to, go to.  

**THERSITES**  
I serve here voluntarily.  

**ACHILLES**  
Your last service was sufferance, 'twas not  
voluntary: no man is beaten voluntary: Ajax was  
here the voluntary, and you as under an impress.  

**THERSITES**  
E'en so; a great deal of your wit, too, lies in your  
sinews, or else there be liars. Hector have a great  
catch, if he knock out either of your brains: a'  
were as good crack a fusty nut with no kernel.  

**ACHILLES**  
What, with me too, Thersites?  

**THERSITES**  
There's Ulysses and old Nestor, whose wit was mouldy  
ere your grandsires had nails on their toes, yoke you  
like draught-oxen and make you plough up the wars.  

**ACHILLES**  
What, what?  

**THERSITES**  
Yes, good sooth: to, Achilles! to, Ajax! to!  

**AJAX**  
I shall cut out your tongue.  

**THERSITES**  
'Tis no matter! I shall speak as much as thou  
afterwards.  

**PATROCLUS**  
No more words, Thersites; peace!  

**THERSITES**  
I will hold my peace when Achilles' brach bids me, shall I?  

**ACHILLES**  
There's for you, Patroclus.  

**THERSITES**  
I will see you hanged, like clotpoles, ere I come  
any more to your tents: I will keep where there is  
wit stirring and leave the faction of fools.  

_Exit_

**PATROCLUS**  
A good riddance.  

**ACHILLES**  
Marry, this, sir, is proclaim'd through all our host:  
That Hector, by the fifth hour of the sun,  
Will with a trumpet 'twixt our tents and Troy  
To-morrow morning call some knight to arms  
That hath a stomach; and such a one that dare  
Maintain--I know not what: 'tis trash. Farewell.  

**AJAX**  
Farewell. Who shall answer him?  

**ACHILLES**  
I know not: 'tis put to lottery; otherwise  
He knew his man.  

**AJAX**  
O, meaning you. I will go learn more of it.  

_Exeunt_

### SCENE II. Troy. A room in Priam's palace.

_Enter PRIAM, HECTOR, TROILUS, PARIS, and HELENUS_

**PRIAM**  
After so many hours, lives, speeches spent,  
Thus once again says Nestor from the Greeks:  
'Deliver Helen, and all damage else--  
As honour, loss of time, travail, expense,  
Wounds, friends, and what else dear that is consumed  
In hot digestion of this cormorant war--  
Shall be struck off.' Hector, what say you to't?  

**HECTOR**  
Though no man lesser fears the Greeks than I  
As far as toucheth my particular,  
Yet, dread Priam,  
There is no lady of more softer bowels,  
More spongy to suck in the sense of fear,  
More ready to cry out 'Who knows what follows?'  
Than Hector is: the wound of peace is surety,  
Surety secure; but modest doubt is call'd  
The beacon of the wise, the tent that searches  
To the bottom of the worst. Let Helen go:  
Since the first sword was drawn about this question,  
Every tithe soul, 'mongst many thousand dismes,  
Hath been as dear as Helen; I mean, of ours:  
If we have lost so many tenths of ours,  
To guard a thing not ours nor worth to us,  
Had it our name, the value of one ten,  
What merit's in that reason which denies  
The yielding of her up?  

**TROILUS**  
Fie, fie, my brother!  
Weigh you the worth and honour of a king  
So great as our dread father in a scale  
Of common ounces? will you with counters sum  
The past proportion of his infinite?  
And buckle in a waist most fathomless  
With spans and inches so diminutive  
As fears and reasons? fie, for godly shame!  

**HELENUS**  
No marvel, though you bite so sharp at reasons,  
You are so empty of them. Should not our father  
Bear the great sway of his affairs with reasons,  
Because your speech hath none that tells him so?  

**TROILUS**  
You are for dreams and slumbers, brother priest;  
You fur your gloves with reason. Here are  
your reasons:  
You know an enemy intends you harm;  
You know a sword employ'd is perilous,  
And reason flies the object of all harm:  
Who marvels then, when Helenus beholds  
A Grecian and his sword, if he do set  
The very wings of reason to his heels  
And fly like chidden Mercury from Jove,  
Or like a star disorb'd? Nay, if we talk of reason,  
Let's shut our gates and sleep: manhood and honour  
Should have hare-hearts, would they but fat  
their thoughts  
With this cramm'd reason: reason and respect  
Make livers pale and lustihood deject.  

**HECTOR**  
Brother, she is not worth what she doth cost  
The holding.  

**TROILUS**  
What is aught, but as 'tis valued?  

**HECTOR**  
But value dwells not in particular will;  
It holds his estimate and dignity  
As well wherein 'tis precious of itself  
As in the prizer: 'tis mad idolatry  
To make the service greater than the god  
And the will dotes that is attributive  
To what infectiously itself affects,  
Without some image of the affected merit.  

**TROILUS**  
I take to-day a wife, and my election  
Is led on in the conduct of my will;  
My will enkindled by mine eyes and ears,  
Two traded pilots 'twixt the dangerous shores  
Of will and judgment: how may I avoid,  
Although my will distaste what it elected,  
The wife I chose? there can be no evasion  
To blench from this and to stand firm by honour:  
We turn not back the silks upon the merchant,  
When we have soil'd them, nor the remainder viands  
We do not throw in unrespective sieve,  
Because we now are full. It was thought meet  
Paris should do some vengeance on the Greeks:  
Your breath of full consent bellied his sails;  
The seas and winds, old wranglers, took a truce  
And did him service: he touch'd the ports desired,  
And for an old aunt whom the Greeks held captive,  
He brought a Grecian queen, whose youth and freshness  
Wrinkles Apollo's, and makes stale the morning.  
Why keep we her? the Grecians keep our aunt:  
Is she worth keeping? why, she is a pearl,  
Whose price hath launch'd above a thousand ships,  
And turn'd crown'd kings to merchants.  
If you'll avouch 'twas wisdom Paris went--  
As you must needs, for you all cried 'Go, go,'\--  
If you'll confess he brought home noble prize--  
As you must needs, for you all clapp'd your hands  
And cried 'Inestimable!'\--why do you now  
The issue of your proper wisdoms rate,  
And do a deed that fortune never did,  
Beggar the estimation which you prized  
Richer than sea and land? O, theft most base,  
That we have stol'n what we do fear to keep!  
But, thieves, unworthy of a thing so stol'n,  
That in their country did them that disgrace,  
We fear to warrant in our native place!  

**CASSANDRA**  
_[Within]_  
Cry, Trojans, cry!  

**PRIAM**  
What noise? what shriek is this?  

**TROILUS**  
'Tis our mad sister, I do know her voice.  

**CASSANDRA**  
_[Within]_  
Cry, Trojans!  

**HECTOR**  
It is Cassandra.  

_Enter CASSANDRA, raving_

**CASSANDRA**  
Cry, Trojans, cry! lend me ten thousand eyes,  
And I will fill them with prophetic tears.  

**HECTOR**  
Peace, sister, peace!  

**CASSANDRA**  
Virgins and boys, mid-age and wrinkled eld,  
Soft infancy, that nothing canst but cry,  
Add to my clamours! let us pay betimes  
A moiety of that mass of moan to come.  
Cry, Trojans, cry! practise your eyes with tears!  
Troy must not be, nor goodly Ilion stand;  
Our firebrand brother, Paris, burns us all.  
Cry, Trojans, cry! a Helen and a woe:  
Cry, cry! Troy burns, or else let Helen go.  

_Exit_

**HECTOR**  
Now, youthful Troilus, do not these high strains  
Of divination in our sister work  
Some touches of remorse? or is your blood  
So madly hot that no discourse of reason,  
Nor fear of bad success in a bad cause,  
Can qualify the same?  

**TROILUS**  
Why, brother Hector,  
We may not think the justness of each act  
Such and no other than event doth form it,  
Nor once deject the courage of our minds,  
Because Cassandra's mad: her brain-sick raptures  
Cannot distaste the goodness of a quarrel  
Which hath our several honours all engaged  
To make it gracious. For my private part,  
I am no more touch'd than all Priam's sons:  
And Jove forbid there should be done amongst us  
Such things as might offend the weakest spleen  
To fight for and maintain!  

**PARIS**  
Else might the world convince of levity  
As well my undertakings as your counsels:  
But I attest the gods, your full consent  
Gave wings to my propension and cut off  
All fears attending on so dire a project.  
For what, alas, can these my single arms?  
What Propugnation is in one man's valour,  
To stand the push and enmity of those  
This quarrel would excite? Yet, I protest,  
Were I alone to pass the difficulties  
And had as ample power as I have will,  
Paris should ne'er retract what he hath done,  
Nor faint in the pursuit.  

**PRIAM**  
Paris, you speak  
Like one besotted on your sweet delights:  
You have the honey still, but these the gall;  
So to be valiant is no praise at all.  

**PARIS**  
Sir, I propose not merely to myself  
The pleasures such a beauty brings with it;  
But I would have the soil of her fair rape  
Wiped off, in honourable keeping her.  
What treason were it to the ransack'd queen,  
Disgrace to your great worths and shame to me,  
Now to deliver her possession up  
On terms of base compulsion! Can it be  
That so degenerate a strain as this  
Should once set footing in your generous bosoms?  
There's not the meanest spirit on our party  
Without a heart to dare or sword to draw  
When Helen is defended, nor none so noble  
Whose life were ill bestow'd or death unfamed  
Where Helen is the subject; then, I say,  
Well may we fight for her whom, we know well,  
The world's large spaces cannot parallel.  

**HECTOR**  
Paris and Troilus, you have both said well,  
And on the cause and question now in hand  
Have glozed, but superficially: not much  
Unlike young men, whom Aristotle thought  
Unfit to hear moral philosophy:  
The reasons you allege do more conduce  
To the hot passion of distemper'd blood  
Than to make up a free determination  
'Twixt right and wrong, for pleasure and revenge  
Have ears more deaf than adders to the voice  
Of any true decision. Nature craves  
All dues be render'd to their owners: now,  
What nearer debt in all humanity  
Than wife is to the husband? If this law  
Of nature be corrupted through affection,  
And that great minds, of partial indulgence  
To their benumbed wills, resist the same,  
There is a law in each well-order'd nation  
To curb those raging appetites that are  
Most disobedient and refractory.  
If Helen then be wife to Sparta's king,  
As it is known she is, these moral laws  
Of nature and of nations speak aloud  
To have her back return'd: thus to persist  
In doing wrong extenuates not wrong,  
But makes it much more heavy. Hector's opinion  
Is this in way of truth; yet ne'ertheless,  
My spritely brethren, I propend to you  
In resolution to keep Helen still,  
For 'tis a cause that hath no mean dependance  
Upon our joint and several dignities.  

**TROILUS**  
Why, there you touch'd the life of our design:  
Were it not glory that we more affected  
Than the performance of our heaving spleens,  
I would not wish a drop of Trojan blood  
Spent more in her defence. But, worthy Hector,  
She is a theme of honour and renown,  
A spur to valiant and magnanimous deeds,  
Whose present courage may beat down our foes,  
And fame in time to come canonize us;  
For, I presume, brave Hector would not lose  
So rich advantage of a promised glory  
As smiles upon the forehead of this action  
For the wide world's revenue.  

**HECTOR**  
I am yours,  
You valiant offspring of great Priamus.  
I have a roisting challenge sent amongst  
The dun and factious nobles of the Greeks  
Will strike amazement to their drowsy spirits:  
I was advertised their great general slept,  
Whilst emulation in the army crept:  
This, I presume, will wake him.  

_Exeunt_

### SCENE III. The Grecian camp. Before Achilles' tent.

_Enter THERSITES, solus_

**THERSITES**  
How now, Thersites! what lost in the labyrinth of  
thy fury! Shall the elephant Ajax carry it thus? He  
beats me, and I rail at him: O, worthy satisfaction!  
would it were otherwise; that I could beat him,  
whilst he railed at me. 'Sfoot, I'll learn to  
conjure and raise devils, but I'll see some issue of  
my spiteful execrations. Then there's Achilles, a  
rare enginer! If Troy be not taken till these two  
undermine it, the walls will stand till they fall of  
themselves. O thou great thunder-darter of Olympus,  
forget that thou art Jove, the king of gods and,  
Mercury, lose all the serpentine craft of thy  
caduceus, if ye take not that little, little less  
than little wit from them that they have! which  
short-armed ignorance itself knows is so abundant  
scarce, it will not in circumvention deliver a fly  
from a spider, without drawing their massy irons and  
cutting the web. After this, the vengeance on the  
whole camp! or rather, the bone-ache! for that,  
methinks, is the curse dependent on those that war  
for a placket. I have said my prayers and devil Envy  
say Amen. What ho! my Lord Achilles!  

_Enter PATROCLUS_

**PATROCLUS**  
Who's there? Thersites! Good Thersites, come in and rail.  

**THERSITES**  
If I could have remembered a gilt counterfeit, thou  
wouldst not have slipped out of my contemplation: but  
it is no matter; thyself upon thyself! The common  
curse of mankind, folly and ignorance, be thine in  
great revenue! heaven bless thee from a tutor, and  
discipline come not near thee! Let thy blood be thy  
direction till thy death! then if she that lays thee  
out says thou art a fair corse, I'll be sworn and  
sworn upon't she never shrouded any but lazars.  
Amen. Where's Achilles?  

**PATROCLUS**  
What, art thou devout? wast thou in prayer?  

**THERSITES**  
Ay: the heavens hear me!  

_Enter ACHILLES_

**ACHILLES**  
Who's there?  

**PATROCLUS**  
Thersites, my lord.  

**ACHILLES**  
Where, where? Art thou come? why, my cheese, my  
digestion, why hast thou not served thyself in to  
my table so many meals? Come, what's Agamemnon?  

**THERSITES**  
Thy commander, Achilles. Then tell me, Patroclus,  
what's Achilles?  

**PATROCLUS**  
Thy lord, Thersites: then tell me, I pray thee,  
what's thyself?  

**THERSITES**  
Thy knower, Patroclus: then tell me, Patroclus,  
what art thou?  

**PATROCLUS**  
Thou mayst tell that knowest.  

**ACHILLES**  
O, tell, tell.  

**THERSITES**  
I'll decline the whole question. Agamemnon commands  
Achilles; Achilles is my lord; I am Patroclus'  
knower, and Patroclus is a fool.  

**PATROCLUS**  
You rascal!  

**THERSITES**  
Peace, fool! I have not done.  

**ACHILLES**  
He is a privileged man. Proceed, Thersites.  

**THERSITES**  
Agamemnon is a fool; Achilles is a fool; Thersites  
is a fool, and, as aforesaid, Patroclus is a fool.  

**ACHILLES**  
Derive this; come.  

**THERSITES**  
Agamemnon is a fool to offer to command Achilles;  
Achilles is a fool to be commanded of Agamemnon;  
Thersites is a fool to serve such a fool, and  
Patroclus is a fool positive.  

**PATROCLUS**  
Why am I a fool?  

**THERSITES**  
Make that demand of the prover. It suffices me thou  
art. Look you, who comes here?  

**ACHILLES**  
Patroclus, I'll speak with nobody.  
Come in with me, Thersites.  

_Exit_

**THERSITES**  
Here is such patchery, such juggling and such  
knavery! all the argument is a cuckold and a  
whore; a good quarrel to draw emulous factions  
and bleed to death upon. Now, the dry serpigo on  
the subject! and war and lechery confound all!  

_Exit_

_Enter AGAMEMNON, ULYSSES, NESTOR, DIOMEDES, and AJAX_

**AGAMEMNON**  
Where is Achilles?  

**PATROCLUS**  
Within his tent; but ill disposed, my lord.  

**AGAMEMNON**  
Let it be known to him that we are here.  
He shent our messengers; and we lay by  
Our appertainments, visiting of him:  
Let him be told so; lest perchance he think  
We dare not move the question of our place,  
Or know not what we are.  

**PATROCLUS**  
I shall say so to him.  

_Exit_

**ULYSSES**  
We saw him at the opening of his tent:  
He is not sick.  

**AJAX**  
Yes, lion-sick, sick of proud heart: you may call it  
melancholy, if you will favour the man; but, by my  
head, 'tis pride: but why, why? let him show us the  
cause. A word, my lord.  

_Takes AGAMEMNON aside_

**NESTOR**  
What moves Ajax thus to bay at him?  

**ULYSSES**  
Achilles hath inveigled his fool from him.  

**NESTOR**  
Who, Thersites?  

**ULYSSES**  
He.  

**NESTOR**  
Then will Ajax lack matter, if he have lost his argument.  

**ULYSSES**  
No, you see, he is his argument that has his  
argument, Achilles.  

**NESTOR**  
All the better; their fraction is more our wish than  
their faction: but it was a strong composure a fool  
could disunite.  

**ULYSSES**  
The amity that wisdom knits not, folly may easily  
untie. Here comes Patroclus.  

_Re-enter PATROCLUS_

**NESTOR**  
No Achilles with him.  

**ULYSSES**  
The elephant hath joints, but none for courtesy:  
his legs are legs for necessity, not for flexure.  

**PATROCLUS**  
Achilles bids me say, he is much sorry,  
If any thing more than your sport and pleasure  
Did move your greatness and this noble state  
To call upon him; he hopes it is no other  
But for your health and your digestion sake,  
And after-dinner's breath.  

**AGAMEMNON**  
Hear you, Patroclus:  
We are too well acquainted with these answers:  
But his evasion, wing'd thus swift with scorn,  
Cannot outfly our apprehensions.  
Much attribute he hath, and much the reason  
Why we ascribe it to him; yet all his virtues,  
Not virtuously on his own part beheld,  
Do in our eyes begin to lose their gloss,  
Yea, like fair fruit in an unwholesome dish,  
Are like to rot untasted. Go and tell him,  
We come to speak with him; and you shall not sin,  
If you do say we think him over-proud  
And under-honest, in self-assumption greater  
Than in the note of judgment; and worthier  
than himself  
Here tend the savage strangeness he puts on,  
Disguise the holy strength of their command,  
And underwrite in an observing kind  
His humorous predominance; yea, watch  
His pettish lunes, his ebbs, his flows, as if  
The passage and whole carriage of this action  
Rode on his tide. Go tell him this, and add,  
That if he overhold his price so much,  
We'll none of him; but let him, like an engine  
Not portable, lie under this report:  
'Bring action hither, this cannot go to war:  
A stirring dwarf we do allowance give  
Before a sleeping giant.' Tell him so.  

**PATROCLUS**  
I shall; and bring his answer presently.  

_Exit_

**AGAMEMNON**  
In second voice we'll not be satisfied;  
We come to speak with him. Ulysses, enter you.  

_Exit ULYSSES_

**AJAX**  
What is he more than another?  

**AGAMEMNON**  
No more than what he thinks he is.  

**AJAX**  
Is he so much? Do you not think he thinks himself a  
better man than I am?  

**AGAMEMNON**  
No question.  

**AJAX**  
Will you subscribe his thought, and say he is?  

**AGAMEMNON**  
No, noble Ajax; you are as strong, as valiant, as  
wise, no less noble, much more gentle, and altogether  
more tractable.  

**AJAX**  
Why should a man be proud? How doth pride grow? I  
know not what pride is.  

**AGAMEMNON**  
Your mind is the clearer, Ajax, and your virtues the  
fairer. He that is proud eats up himself: pride is  
his own glass, his own trumpet, his own chronicle;  
and whatever praises itself but in the deed, devours  
the deed in the praise.  

**AJAX**  
I do hate a proud man, as I hate the engendering of toads.  

**NESTOR**  
Yet he loves himself: is't not strange?  

_[Aside]_  
_Re-enter ULYSSES_

**ULYSSES**  
Achilles will not to the field to-morrow.  

**AGAMEMNON**  
What's his excuse?  

**ULYSSES**  
He doth rely on none,  
But carries on the stream of his dispose  
Without observance or respect of any,  
In will peculiar and in self-admission.  

**AGAMEMNON**  
Why will he not upon our fair request  
Untent his person and share the air with us?  

**ULYSSES**  
Things small as nothing, for request's sake only,  
He makes important: possess'd he is with greatness,  
And speaks not to himself but with a pride  
That quarrels at self-breath: imagined worth  
Holds in his blood such swoln and hot discourse  
That 'twixt his mental and his active parts  
Kingdom'd Achilles in commotion rages  
And batters down himself: what should I say?  
He is so plaguy proud that the death-tokens of it  
Cry 'No recovery.'  

**AGAMEMNON**  
Let Ajax go to him.  
Dear lord, go you and greet him in his tent:  
'Tis said he holds you well, and will be led  
At your request a little from himself.  

**ULYSSES**  
O Agamemnon, let it not be so!  
We'll consecrate the steps that Ajax makes  
When they go from Achilles: shall the proud lord  
That bastes his arrogance with his own seam  
And never suffers matter of the world  
Enter his thoughts, save such as do revolve  
And ruminate himself, shall he be worshipp'd  
Of that we hold an idol more than he?  
No, this thrice worthy and right valiant lord  
Must not so stale his palm, nobly acquired;  
Nor, by my will, assubjugate his merit,  
As amply titled as Achilles is,  
By going to Achilles:  
That were to enlard his fat already pride  
And add more coals to Cancer when he burns  
With entertaining great Hyperion.  
This lord go to him! Jupiter forbid,  
And say in thunder 'Achilles go to him.'  

**NESTOR**  
_[Aside to DIOMEDES]_  
O, this is well; he rubs the  
vein of him.  

**DIOMEDES**  
_[Aside to NESTOR]_  
And how his silence drinks up  
this applause!  

**AJAX**  
If I go to him, with my armed fist I'll pash him o'er the face.  

**AGAMEMNON**  
O, no, you shall not go.  

**AJAX**  
An a' be proud with me, I'll pheeze his pride:  
Let me go to him.  

**ULYSSES**  
Not for the worth that hangs upon our quarrel.  

**AJAX**  
A paltry, insolent fellow!  

**NESTOR**  
How he describes himself!  

**AJAX**  
Can he not be sociable?  

**ULYSSES**  
The raven chides blackness.  

**AJAX**  
I'll let his humours blood.  

**AGAMEMNON**  
He will be the physician that should be the patient.  

**AJAX**  
An all men were o' my mind,--  

**ULYSSES**  
Wit would be out of fashion.  

**AJAX**  
A' should not bear it so, a' should eat swords first:  
shall pride carry it?  

**NESTOR**  
An 'twould, you'ld carry half.  

**ULYSSES**  
A' would have ten shares.  

**AJAX**  
I will knead him; I'll make him supple.  

**NESTOR**  
He's not yet through warm: force him with praises:  
pour in, pour in; his ambition is dry.  

**ULYSSES**  
_[To AGAMEMNON]_  
My lord, you feed too much on this dislike.  

**NESTOR**  
Our noble general, do not do so.  

**DIOMEDES**  
You must prepare to fight without Achilles.  

**ULYSSES**  
Why, 'tis this naming of him does him harm.  
Here is a man--but 'tis before his face;  
I will be silent.  

**NESTOR**  
Wherefore should you so?  
He is not emulous, as Achilles is.  

**ULYSSES**  
Know the whole world, he is as valiant.  

**AJAX**  
A whoreson dog, that shall pelter thus with us!  
Would he were a Trojan!  

**NESTOR**  
What a vice were it in Ajax now,--  

**ULYSSES**  
If he were proud,--  

**DIOMEDES**  
Or covetous of praise,--  

**ULYSSES**  
Ay, or surly borne,--  

**DIOMEDES**  
Or strange, or self-affected!  

**ULYSSES**  
Thank the heavens, lord, thou art of sweet composure;  
Praise him that got thee, she that gave thee suck:  
Famed be thy tutor, and thy parts of nature  
Thrice famed, beyond all erudition:  
But he that disciplined thy arms to fight,  
Let Mars divide eternity in twain,  
And give him half: and, for thy vigour,  
Bull-bearing Milo his addition yield  
To sinewy Ajax. I will not praise thy wisdom,  
Which, like a bourn, a pale, a shore, confines  
Thy spacious and dilated parts: here's Nestor;  
Instructed by the antiquary times,  
He must, he is, he cannot but be wise:  
Put pardon, father Nestor, were your days  
As green as Ajax' and your brain so temper'd,  
You should not have the eminence of him,  
But be as Ajax.  

**AJAX**  
Shall I call you father?  

**NESTOR**  
Ay, my good son.  

**DIOMEDES**  
Be ruled by him, Lord Ajax.  

**ULYSSES**  
There is no tarrying here; the hart Achilles  
Keeps thicket. Please it our great general  
To call together all his state of war;  
Fresh kings are come to Troy: to-morrow  
We must with all our main of power stand fast:  
And here's a lord,--come knights from east to west,  
And cull their flower, Ajax shall cope the best.  

**AGAMEMNON**  
Go we to council. Let Achilles sleep:  
Light boats sail swift, though greater hulks draw deep.  

_Exeunt_

# ACT III

### SCENE I. Troy. Priam's palace.

_Enter a Servant and PANDARUS_

**PANDARUS**  
Friend, you! pray you, a word: do not you follow  
the young Lord Paris?  

**Servant**  
Ay, sir, when he goes before me.  

**PANDARUS**  
You depend upon him, I mean?  

**Servant**  
Sir, I do depend upon the lord.  

**PANDARUS**  
You depend upon a noble gentleman; I must needs  
praise him.  

**Servant**  
The lord be praised!  

**PANDARUS**  
You know me, do you not?  

**Servant**  
Faith, sir, superficially.  

**PANDARUS**  
Friend, know me better; I am the Lord Pandarus.  

**Servant**  
I hope I shall know your honour better.  

**PANDARUS**  
I do desire it.  

**Servant**  
You are in the state of grace.  

**PANDARUS**  
Grace! not so, friend: honour and lordship are my titles.  

_Music within_

What music is this?  

**Servant**  
I do but partly know, sir: it is music in parts.  

**PANDARUS**  
Know you the musicians?  

**Servant**  
Wholly, sir.  

**PANDARUS**  
Who play they to?  

**Servant**  
To the hearers, sir.  

**PANDARUS**  
At whose pleasure, friend  

**Servant**  
At mine, sir, and theirs that love music.  

**PANDARUS**  
Command, I mean, friend.  

**Servant**  
Who shall I command, sir?  

**PANDARUS**  
Friend, we understand not one another: I am too  
courtly and thou art too cunning. At whose request  
do these men play?  

**Servant**  
That's to 't indeed, sir: marry, sir, at the request  
of Paris my lord, who's there in person; with him,  
the mortal Venus, the heart-blood of beauty, love's  
invisible soul,--  

**PANDARUS**  
Who, my cousin Cressida?  

**Servant**  
No, sir, Helen: could you not find out that by her  
attributes?  

**PANDARUS**  
It should seem, fellow, that thou hast not seen the  
Lady Cressida. I come to speak with Paris from the  
Prince Troilus: I will make a complimental assault  
upon him, for my business seethes.  

**Servant**  
Sodden business! there's a stewed phrase indeed!  

_Enter PARIS and HELEN, attended_

**PANDARUS**  
Fair be to you, my lord, and to all this fair  
company! fair desires, in all fair measure,  
fairly guide them! especially to you, fair queen!  
fair thoughts be your fair pillow!  

**HELEN**  
Dear lord, you are full of fair words.  

**PANDARUS**  
You speak your fair pleasure, sweet queen. Fair  
prince, here is good broken music.  

**PARIS**  
You have broke it, cousin: and, by my life, you  
shall make it whole again; you shall piece it out  
with a piece of your performance. Nell, he is full  
of harmony.  

**PANDARUS**  
Truly, lady, no.  

**HELEN**  
O, sir,--  

**PANDARUS**  
Rude, in sooth; in good sooth, very rude.  

**PARIS**  
Well said, my lord! well, you say so in fits.  

**PANDARUS**  
I have business to my lord, dear queen. My lord,  
will you vouchsafe me a word?  

**HELEN**  
Nay, this shall not hedge us out: we'll hear you  
sing, certainly.  

**PANDARUS**  
Well, sweet queen. you are pleasant with me. But,  
marry, thus, my lord: my dear lord and most esteemed  
friend, your brother Troilus,--  

**HELEN**  
My Lord Pandarus; honey-sweet lord,--  

**PANDARUS**  
Go to, sweet queen, to go:--commends himself most  
affectionately to you,--  

**HELEN**  
You shall not bob us out of our melody: if you do,  
our melancholy upon your head!  

**PANDARUS**  
Sweet queen, sweet queen! that's a sweet queen, i' faith.  

**HELEN**  
And to make a sweet lady sad is a sour offence.  

**PANDARUS**  
Nay, that shall not serve your turn; that shall not,  
in truth, la. Nay, I care not for such words; no,  
no. And, my lord, he desires you, that if the king  
call for him at supper, you will make his excuse.  

**HELEN**  
My Lord Pandarus,--  

**PANDARUS**  
What says my sweet queen, my very very sweet queen?  

**PARIS**  
What exploit's in hand? where sups he to-night?  

**HELEN**  
Nay, but, my lord,--  

**PANDARUS**  
What says my sweet queen? My cousin will fall out  
with you. You must not know where he sups.  

**PARIS**  
I'll lay my life, with my disposer Cressida.  

**PANDARUS**  
No, no, no such matter; you are wide: come, your  
disposer is sick.  

**PARIS**  
Well, I'll make excuse.  

**PANDARUS**  
Ay, good my lord. Why should you say Cressida? no,  
your poor disposer's sick.  

**PARIS**  
I spy.  

**PANDARUS**  
You spy! what do you spy? Come, give me an  
instrument. Now, sweet queen.  

**HELEN**  
Why, this is kindly done.  

**PANDARUS**  
My niece is horribly in love with a thing you have,  
sweet queen.  

**HELEN**  
She shall have it, my lord, if it be not my lord Paris.  

**PANDARUS**  
He! no, she'll none of him; they two are twain.  

**HELEN**  
Falling in, after falling out, may make them three.  

**PANDARUS**  
Come, come, I'll hear no more of this; I'll sing  
you a song now.  

**HELEN**  
Ay, ay, prithee now. By my troth, sweet lord, thou  
hast a fine forehead.  

**PANDARUS**  
Ay, you may, you may.  

**HELEN**  
Let thy song be love: this love will undo us all.  
O Cupid, Cupid, Cupid!  

**PANDARUS**  
Love! ay, that it shall, i' faith.  

**PARIS**  
Ay, good now, love, love, nothing but love.  

**PANDARUS**  
In good troth, it begins so.  

_Sings_

Love, love, nothing but love, still more!  
For, O, love's bow  
Shoots buck and doe:  
The shaft confounds,  
Not that it wounds,  
But tickles still the sore.  
These lovers cry Oh! oh! they die!  
Yet that which seems the wound to kill,  
Doth turn oh! oh! to ha! ha! he!  
So dying love lives still:  
Oh! oh! a while, but ha! ha! ha!  
Oh! oh! groans out for ha! ha! ha!  
Heigh-ho!  

**HELEN**  
In love, i' faith, to the very tip of the nose.  

**PARIS**  
He eats nothing but doves, love, and that breeds hot  
blood, and hot blood begets hot thoughts, and hot  
thoughts beget hot deeds, and hot deeds is love.  

**PANDARUS**  
Is this the generation of love? hot blood, hot  
thoughts, and hot deeds? Why, they are vipers:  
is love a generation of vipers? Sweet lord, who's  
a-field to-day?  

**PARIS**  
Hector, Deiphobus, Helenus, Antenor, and all the  
gallantry of Troy: I would fain have armed to-day,  
but my Nell would not have it so. How chance my  
brother Troilus went not?  

**HELEN**  
He hangs the lip at something: you know all, Lord Pandarus.  

**PANDARUS**  
Not I, honey-sweet queen. I long to hear how they  
sped to-day. You'll remember your brother's excuse?  

**PARIS**  
To a hair.  

**PANDARUS**  
Farewell, sweet queen.  

**HELEN**  
Commend me to your niece.  

**PANDARUS**  
I will, sweet queen.  

_Exit_

_A retreat sounded_

**PARIS**  
They're come from field: let us to Priam's hall,  
To greet the warriors. Sweet Helen, I must woo you  
To help unarm our Hector: his stubborn buckles,  
With these your white enchanting fingers touch'd,  
Shall more obey than to the edge of steel  
Or force of Greekish sinews; you shall do more  
Than all the island kings,--disarm great Hector.  

**HELEN**  
'Twill make us proud to be his servant, Paris;  
Yea, what he shall receive of us in duty  
Gives us more palm in beauty than we have,  
Yea, overshines ourself.  

**PARIS**  
Sweet, above thought I love thee.  

_Exeunt_

### SCENE II. The same. Pandarus' orchard.

_Enter PANDARUS and Troilus 's Boy, meeting_

**PANDARUS**  
How now! where's thy master? at my cousin  
Cressida's?  

**Boy**  
No, sir; he stays for you to conduct him thither.  

**PANDARUS**  
O, here he comes.  

_Enter TROILUS_

How now, how now!  

**TROILUS**  
Sirrah, walk off.  

_Exit Boy_

**PANDARUS**  
Have you seen my cousin?  

**TROILUS**  
No, Pandarus: I stalk about her door,  
Like a strange soul upon the Stygian banks  
Staying for waftage. O, be thou my Charon,  
And give me swift transportance to those fields  
Where I may wallow in the lily-beds  
Proposed for the deserver! O gentle Pandarus,  
From Cupid's shoulder pluck his painted wings  
And fly with me to Cressid!  

**PANDARUS**  
Walk here i' the orchard, I'll bring her straight.  

_Exit_

**TROILUS**  
I am giddy; expectation whirls me round.  
The imaginary relish is so sweet  
That it enchants my sense: what will it be,  
When that the watery palate tastes indeed  
Love's thrice repured nectar? death, I fear me,  
Swooning destruction, or some joy too fine,  
Too subtle-potent, tuned too sharp in sweetness,  
For the capacity of my ruder powers:  
I fear it much; and I do fear besides,  
That I shall lose distinction in my joys;  
As doth a battle, when they charge on heaps  
The enemy flying.  

_Re-enter PANDARUS_

**PANDARUS**  
She's making her ready, she'll come straight: you  
must be witty now. She does so blush, and fetches  
her wind so short, as if she were frayed with a  
sprite: I'll fetch her. It is the prettiest  
villain: she fetches her breath as short as a  
new-ta'en sparrow.  

_Exit_

**TROILUS**  
Even such a passion doth embrace my bosom:  
My heart beats thicker than a feverous pulse;  
And all my powers do their bestowing lose,  
Like vassalage at unawares encountering  
The eye of majesty.  

_Re-enter PANDARUS with CRESSIDA_

**PANDARUS**  
Come, come, what need you blush? shame's a baby.  
Here she is now: swear the oaths now to her that  
you have sworn to me. What, are you gone again?  
you must be watched ere you be made tame, must you?  
Come your ways, come your ways; an you draw backward,  
we'll put you i' the fills. Why do you not speak to  
her? Come, draw this curtain, and let's see your  
picture. Alas the day, how loath you are to offend  
daylight! an 'twere dark, you'ld close sooner.  
So, so; rub on, and kiss the mistress. How now!  
a kiss in fee-farm! build there, carpenter; the air  
is sweet. Nay, you shall fight your hearts out ere  
I part you. The falcon as the tercel, for all the  
ducks i' the river: go to, go to.  

**TROILUS**  
You have bereft me of all words, lady.  

**PANDARUS**  
Words pay no debts, give her deeds: but she'll  
bereave you o' the deeds too, if she call your  
activity in question. What, billing again? Here's  
'In witness whereof the parties interchangeably'\--  
Come in, come in: I'll go get a fire.  

_Exit_

**CRESSIDA**  
Will you walk in, my lord?  

**TROILUS**  
O Cressida, how often have I wished me thus!  

**CRESSIDA**  
Wished, my lord! The gods grant,--O my lord!  

**TROILUS**  
What should they grant? what makes this pretty  
abruption? What too curious dreg espies my sweet  
lady in the fountain of our love?  

**CRESSIDA**  
More dregs than water, if my fears have eyes.  

**TROILUS**  
Fears make devils of cherubims; they never see truly.  

**CRESSIDA**  
Blind fear, that seeing reason leads, finds safer  
footing than blind reason stumbling without fear: to  
fear the worst oft cures the worse.  

**TROILUS**  
O, let my lady apprehend no fear: in all Cupid's  
pageant there is presented no monster.  

**CRESSIDA**  
Nor nothing monstrous neither?  

**TROILUS**  
Nothing, but our undertakings; when we vow to weep  
seas, live in fire, eat rocks, tame tigers; thinking  
it harder for our mistress to devise imposition  
enough than for us to undergo any difficulty imposed.  
This is the monstruosity in love, lady, that the will  
is infinite and the execution confined, that the  
desire is boundless and the act a slave to limit.  

**CRESSIDA**  
They say all lovers swear more performance than they  
are able and yet reserve an ability that they never  
perform, vowing more than the perfection of ten and  
discharging less than the tenth part of one. They  
that have the voice of lions and the act of hares,  
are they not monsters?  

**TROILUS**  
Are there such? such are not we: praise us as we  
are tasted, allow us as we prove; our head shall go  
bare till merit crown it: no perfection in reversion  
shall have a praise in present: we will not name  
desert before his birth, and, being born, his addition  
shall be humble. Few words to fair faith: Troilus  
shall be such to Cressid as what envy can say worst  
shall be a mock for his truth, and what truth can  
speak truest not truer than Troilus.  

**CRESSIDA**  
Will you walk in, my lord?  

_Re-enter PANDARUS_

**PANDARUS**  
What, blushing still? have you not done talking yet?  

**CRESSIDA**  
Well, uncle, what folly I commit, I dedicate to you.  

**PANDARUS**  
I thank you for that: if my lord get a boy of you,  
you'll give him me. Be true to my lord: if he  
flinch, chide me for it.  

**TROILUS**  
You know now your hostages; your uncle's word and my  
firm faith.  

**PANDARUS**  
Nay, I'll give my word for her too: our kindred,  
though they be long ere they are wooed, they are  
constant being won: they are burs, I can tell you;  
they'll stick where they are thrown.  

**CRESSIDA**  
Boldness comes to me now, and brings me heart.  
Prince Troilus, I have loved you night and day  
For many weary months.  

**TROILUS**  
Why was my Cressid then so hard to win?  

**CRESSIDA**  
Hard to seem won: but I was won, my lord,  
With the first glance that ever--pardon me--  
If I confess much, you will play the tyrant.  
I love you now; but not, till now, so much  
But I might master it: in faith, I lie;  
My thoughts were like unbridled children, grown  
Too headstrong for their mother. See, we fools!  
Why have I blabb'd? who shall be true to us,  
When we are so unsecret to ourselves?  
But, though I loved you well, I woo'd you not;  
And yet, good faith, I wish'd myself a man,  
Or that we women had men's privilege  
Of speaking first. Sweet, bid me hold my tongue,  
For in this rapture I shall surely speak  
The thing I shall repent. See, see, your silence,  
Cunning in dumbness, from my weakness draws  
My very soul of counsel! stop my mouth.  

**TROILUS**  
And shall, albeit sweet music issues thence.  

**PANDARUS**  
Pretty, i' faith.  

**CRESSIDA**  
My lord, I do beseech you, pardon me;  
'Twas not my purpose, thus to beg a kiss:  
I am ashamed. O heavens! what have I done?  
For this time will I take my leave, my lord.  

**TROILUS**  
Your leave, sweet Cressid!  

**PANDARUS**  
Leave! an you take leave till to-morrow morning,--  

**CRESSIDA**  
Pray you, content you.  

**TROILUS**  
What offends you, lady?  

**CRESSIDA**  
Sir, mine own company.  

**TROILUS**  
You cannot shun Yourself.  

**CRESSIDA**  
Let me go and try:  
I have a kind of self resides with you;  
But an unkind self, that itself will leave,  
To be another's fool. I would be gone:  
Where is my wit? I know not what I speak.  

**TROILUS**  
Well know they what they speak that speak so wisely.  

**CRESSIDA**  
Perchance, my lord, I show more craft than love;  
And fell so roundly to a large confession,  
To angle for your thoughts: but you are wise,  
Or else you love not, for to be wise and love  
Exceeds man's might; that dwells with gods above.  

**TROILUS**  
O that I thought it could be in a woman--  
As, if it can, I will presume in you--  
To feed for aye her ramp and flames of love;  
To keep her constancy in plight and youth,  
Outliving beauty's outward, with a mind  
That doth renew swifter than blood decays!  
Or that persuasion could but thus convince me,  
That my integrity and truth to you  
Might be affronted with the match and weight  
Of such a winnow'd purity in love;  
How were I then uplifted! but, alas!  
I am as true as truth's simplicity  
And simpler than the infancy of truth.  

**CRESSIDA**  
In that I'll war with you.  

**TROILUS**  
O virtuous fight,  
When right with right wars who shall be most right!  
True swains in love shall in the world to come  
Approve their truths by Troilus: when their rhymes,  
Full of protest, of oath and big compare,  
Want similes, truth tired with iteration,  
As true as steel, as plantage to the moon,  
As sun to day, as turtle to her mate,  
As iron to adamant, as earth to the centre,  
Yet, after all comparisons of truth,  
As truth's authentic author to be cited,  
'As true as Troilus' shall crown up the verse,  
And sanctify the numbers.  

**CRESSIDA**  
Prophet may you be!  
If I be false, or swerve a hair from truth,  
When time is old and hath forgot itself,  
When waterdrops have worn the stones of Troy,  
And blind oblivion swallow'd cities up,  
And mighty states characterless are grated  
To dusty nothing, yet let memory,  
From false to false, among false maids in love,  
Upbraid my falsehood! when they've said 'as false  
As air, as water, wind, or sandy earth,  
As fox to lamb, as wolf to heifer's calf,  
Pard to the hind, or stepdame to her son,'  
'Yea,' let them say, to stick the heart of falsehood,  
'As false as Cressid.'  

**PANDARUS**  
Go to, a bargain made: seal it, seal it; I'll be the  
witness. Here I hold your hand, here my cousin's.  
If ever you prove false one to another, since I have  
taken such pains to bring you together, let all  
pitiful goers-between be called to the world's end  
after my name; call them all Pandars; let all  
constant men be Troiluses, all false women Cressids,  
and all brokers-between Pandars! say, amen.  

**TROILUS**  
Amen.  

**CRESSIDA**  
Amen.  

**PANDARUS**  
Amen. Whereupon I will show you a chamber with a  
bed; which bed, because it shall not speak of your  
pretty encounters, press it to death: away!  
And Cupid grant all tongue-tied maidens here  
Bed, chamber, Pandar to provide this gear!  

_Exeunt_

### SCENE III. The Grecian camp. Before Achilles' tent.

_Enter AGAMEMNON, ULYSSES, DIOMEDES, NESTOR, AJAX, MENELAUS, and CALCHAS_

**CALCHAS**  
Now, princes, for the service I have done you,  
The advantage of the time prompts me aloud  
To call for recompense. Appear it to your mind  
That, through the sight I bear in things to love,  
I have abandon'd Troy, left my possession,  
Incurr'd a traitor's name; exposed myself,  
From certain and possess'd conveniences,  
To doubtful fortunes; sequestering from me all  
That time, acquaintance, custom and condition  
Made tame and most familiar to my nature,  
And here, to do you service, am become  
As new into the world, strange, unacquainted:  
I do beseech you, as in way of taste,  
To give me now a little benefit,  
Out of those many register'd in promise,  
Which, you say, live to come in my behalf.  

**AGAMEMNON**  
What wouldst thou of us, Trojan? make demand.  

**CALCHAS**  
You have a Trojan prisoner, call'd Antenor,  
Yesterday took: Troy holds him very dear.  
Oft have you--often have you thanks therefore--  
Desired my Cressid in right great exchange,  
Whom Troy hath still denied: but this Antenor,  
I know, is such a wrest in their affairs  
That their negotiations all must slack,  
Wanting his manage; and they will almost  
Give us a prince of blood, a son of Priam,  
In change of him: let him be sent, great princes,  
And he shall buy my daughter; and her presence  
Shall quite strike off all service I have done,  
In most accepted pain.  

**AGAMEMNON**  
Let Diomedes bear him,  
And bring us Cressid hither: Calchas shall have  
What he requests of us. Good Diomed,  
Furnish you fairly for this interchange:  
Withal bring word if Hector will to-morrow  
Be answer'd in his challenge: Ajax is ready.  

**DIOMEDES**  
This shall I undertake; and 'tis a burden  
Which I am proud to bear.  

_Exeunt DIOMEDES and CALCHAS_

_Enter ACHILLES and PATROCLUS, before their tent_

**ULYSSES**  
Achilles stands i' the entrance of his tent:  
Please it our general to pass strangely by him,  
As if he were forgot; and, princes all,  
Lay negligent and loose regard upon him:  
I will come last. 'Tis like he'll question me  
Why such unplausive eyes are bent on him:  
If so, I have derision medicinable,  
To use between your strangeness and his pride,  
Which his own will shall have desire to drink:  
It may be good: pride hath no other glass  
To show itself but pride, for supple knees  
Feed arrogance and are the proud man's fees.  

**AGAMEMNON**  
We'll execute your purpose, and put on  
A form of strangeness as we pass along:  
So do each lord, and either greet him not,  
Or else disdainfully, which shall shake him more  
Than if not look'd on. I will lead the way.  

**ACHILLES**  
What, comes the general to speak with me?  
You know my mind, I'll fight no more 'gainst Troy.  

**AGAMEMNON**  
What says Achilles? would he aught with us?  

**NESTOR**  
Would you, my lord, aught with the general?  

**ACHILLES**  
No.  

**NESTOR**  
Nothing, my lord.  

**AGAMEMNON**  
The better.  

_Exeunt AGAMEMNON and NESTOR_

**ACHILLES**  
Good day, good day.  

**MENELAUS**  
How do you? how do you?  

_Exit_

**ACHILLES**  
What, does the cuckold scorn me?  

**AJAX**  
How now, Patroclus!  

**ACHILLES**  
Good morrow, Ajax.  

**AJAX**  
Ha?  

**ACHILLES**  
Good morrow.  

**AJAX**  
Ay, and good next day too.  

_Exit_

**ACHILLES**  
What mean these fellows? Know they not Achilles?  

**PATROCLUS**  
They pass by strangely: they were used to bend  
To send their smiles before them to Achilles;  
To come as humbly as they used to creep  
To holy altars.  

**ACHILLES**  
What, am I poor of late?  
'Tis certain, greatness, once fall'n out with fortune,  
Must fall out with men too: what the declined is  
He shall as soon read in the eyes of others  
As feel in his own fall; for men, like butterflies,  
Show not their mealy wings but to the summer,  
And not a man, for being simply man,  
Hath any honour, but honour for those honours  
That are without him, as place, riches, favour,  
Prizes of accident as oft as merit:  
Which when they fall, as being slippery standers,  
The love that lean'd on them as slippery too,  
Do one pluck down another and together  
Die in the fall. But 'tis not so with me:  
Fortune and I are friends: I do enjoy  
At ample point all that I did possess,  
Save these men's looks; who do, methinks, find out  
Something not worth in me such rich beholding  
As they have often given. Here is Ulysses;  
I'll interrupt his reading.  
How now Ulysses!  

**ULYSSES**  
Now, great Thetis' son!  

**ACHILLES**  
What are you reading?  

**ULYSSES**  
A strange fellow here  
Writes me: 'That man, how dearly ever parted,  
How much in having, or without or in,  
Cannot make boast to have that which he hath,  
Nor feels not what he owes, but by reflection;  
As when his virtues shining upon others  
Heat them and they retort that heat again  
To the first giver.'  

**ACHILLES**  
This is not strange, Ulysses.  
The beauty that is borne here in the face  
The bearer knows not, but commends itself  
To others' eyes; nor doth the eye itself,  
That most pure spirit of sense, behold itself,  
Not going from itself; but eye to eye opposed  
Salutes each other with each other's form;  
For speculation turns not to itself,  
Till it hath travell'd and is mirror'd there  
Where it may see itself. This is not strange at all.  

**ULYSSES**  
I do not strain at the position,--  
It is familiar,--but at the author's drift;  
Who, in his circumstance, expressly proves  
That no man is the lord of any thing,  
Though in and of him there be much consisting,  
Till he communicate his parts to others:  
Nor doth he of himself know them for aught  
Till he behold them form'd in the applause  
Where they're extended; who, like an arch,  
reverberates  
The voice again, or, like a gate of steel  
Fronting the sun, receives and renders back  
His figure and his heat. I was much wrapt in this;  
And apprehended here immediately  
The unknown Ajax.  
Heavens, what a man is there! a very horse,  
That has he knows not what. Nature, what things there are  
Most abject in regard and dear in use!  
What things again most dear in the esteem  
And poor in worth! Now shall we see to-morrow--  
An act that very chance doth throw upon him--  
Ajax renown'd. O heavens, what some men do,  
While some men leave to do!  
How some men creep in skittish fortune's hall,  
Whiles others play the idiots in her eyes!  
How one man eats into another's pride,  
While pride is fasting in his wantonness!  
To see these Grecian lords!--why, even already  
They clap the lubber Ajax on the shoulder,  
As if his foot were on brave Hector's breast  
And great Troy shrieking.  

**ACHILLES**  
I do believe it; for they pass'd by me  
As misers do by beggars, neither gave to me  
Good word nor look: what, are my deeds forgot?  

**ULYSSES**  
Time hath, my lord, a wallet at his back,  
Wherein he puts alms for oblivion,  
A great-sized monster of ingratitudes:  
Those scraps are good deeds past; which are devour'd  
As fast as they are made, forgot as soon  
As done: perseverance, dear my lord,  
Keeps honour bright: to have done is to hang  
Quite out of fashion, like a rusty mail  
In monumental mockery. Take the instant way;  
For honour travels in a strait so narrow,  
Where one but goes abreast: keep then the path;  
For emulation hath a thousand sons  
That one by one pursue: if you give way,  
Or hedge aside from the direct forthright,  
Like to an enter'd tide, they all rush by  
And leave you hindmost;  
Or like a gallant horse fall'n in first rank,  
Lie there for pavement to the abject rear,  
O'er-run and trampled on: then what they do in present,  
Though less than yours in past, must o'ertop yours;  
For time is like a fashionable host  
That slightly shakes his parting guest by the hand,  
And with his arms outstretch'd, as he would fly,  
Grasps in the comer: welcome ever smiles,  
And farewell goes out sighing. O, let not  
virtue seek  
Remuneration for the thing it was;  
For beauty, wit,  
High birth, vigour of bone, desert in service,  
Love, friendship, charity, are subjects all  
To envious and calumniating time.  
One touch of nature makes the whole world kin,  
That all with one consent praise new-born gawds,  
Though they are made and moulded of things past,  
And give to dust that is a little gilt  
More laud than gilt o'er-dusted.  
The present eye praises the present object.  
Then marvel not, thou great and complete man,  
That all the Greeks begin to worship Ajax;  
Since things in motion sooner catch the eye  
Than what not stirs. The cry went once on thee,  
And still it might, and yet it may again,  
If thou wouldst not entomb thyself alive  
And case thy reputation in thy tent;  
Whose glorious deeds, but in these fields of late,  
Made emulous missions 'mongst the gods themselves  
And drave great Mars to faction.  

**ACHILLES**  
Of this my privacy  
I have strong reasons.  

**ULYSSES**  
But 'gainst your privacy  
The reasons are more potent and heroical:  
'Tis known, Achilles, that you are in love  
With one of Priam's daughters.  

**ACHILLES**  
Ha! known!  

**ULYSSES**  
Is that a wonder?  
The providence that's in a watchful state  
Knows almost every grain of Plutus' gold,  
Finds bottom in the uncomprehensive deeps,  
Keeps place with thought and almost, like the gods,  
Does thoughts unveil in their dumb cradles.  
There is a mystery--with whom relation  
Durst never meddle--in the soul of state;  
Which hath an operation more divine  
Than breath or pen can give expressure to:  
All the commerce that you have had with Troy  
As perfectly is ours as yours, my lord;  
And better would it fit Achilles much  
To throw down Hector than Polyxena:  
But it must grieve young Pyrrhus now at home,  
When fame shall in our islands sound her trump,  
And all the Greekish girls shall tripping sing,  
'Great Hector's sister did Achilles win,  
But our great Ajax bravely beat down him.'  
Farewell, my lord: I as your lover speak;  
The fool slides o'er the ice that you should break.  

_Exit_

**PATROCLUS**  
To this effect, Achilles, have I moved you:  
A woman impudent and mannish grown  
Is not more loathed than an effeminate man  
In time of action. I stand condemn'd for this;  
They think my little stomach to the war  
And your great love to me restrains you thus:  
Sweet, rouse yourself; and the weak wanton Cupid  
Shall from your neck unloose his amorous fold,  
And, like a dew-drop from the lion's mane,  
Be shook to air.  

**ACHILLES**  
Shall Ajax fight with Hector?  

**PATROCLUS**  
Ay, and perhaps receive much honour by him.  

**ACHILLES**  
I see my reputation is at stake  
My fame is shrewdly gored.  

**PATROCLUS**  
O, then, beware;  
Those wounds heal ill that men do give themselves:  
Omission to do what is necessary  
Seals a commission to a blank of danger;  
And danger, like an ague, subtly taints  
Even then when we sit idly in the sun.  

**ACHILLES**  
Go call Thersites hither, sweet Patroclus:  
I'll send the fool to Ajax and desire him  
To invite the Trojan lords after the combat  
To see us here unarm'd: I have a woman's longing,  
An appetite that I am sick withal,  
To see great Hector in his weeds of peace,  
To talk with him and to behold his visage,  
Even to my full of view.  

_Enter THERSITES_

A labour saved!  

**THERSITES**  
A wonder!  

**ACHILLES**  
What?  

**THERSITES**  
Ajax goes up and down the field, asking for himself.  

**ACHILLES**  
How so?  

**THERSITES**  
He must fight singly to-morrow with Hector, and is so  
prophetically proud of an heroical cudgelling that he  
raves in saying nothing.  

**ACHILLES**  
How can that be?  

**THERSITES**  
Why, he stalks up and down like a peacock,--a stride  
and a stand: ruminates like an hostess that hath no  
arithmetic but her brain to set down her reckoning:  
bites his lip with a politic regard, as who should  
say 'There were wit in this head, an 'twould out;'  
and so there is, but it lies as coldly in him as fire  
in a flint, which will not show without knocking.  
The man's undone forever; for if Hector break not his  
neck i' the combat, he'll break 't himself in  
vain-glory. He knows not me: I said 'Good morrow,  
Ajax;' and he replies 'Thanks, Agamemnon.' What think  
you of this man that takes me for the general? He's  
grown a very land-fish, language-less, a monster.  
A plague of opinion! a man may wear it on both  
sides, like a leather jerkin.  

**ACHILLES**  
Thou must be my ambassador to him, Thersites.  

**THERSITES**  
Who, I? why, he'll answer nobody; he professes not  
answering: speaking is for beggars; he wears his  
tongue in's arms. I will put on his presence: let  
Patroclus make demands to me, you shall see the  
pageant of Ajax.  

**ACHILLES**  
To him, Patroclus; tell him I humbly desire the  
valiant Ajax to invite the most valorous Hector  
to come unarmed to my tent, and to procure  
safe-conduct for his person of the magnanimous  
and most illustrious six-or-seven-times-honoured  
captain-general of the Grecian army, Agamemnon,  
et cetera. Do this.  

**PATROCLUS**  
Jove bless great Ajax!  

**THERSITES**  
Hum!  

**PATROCLUS**  
I come from the worthy Achilles,--  

**THERSITES**  
Ha!  

**PATROCLUS**  
Who most humbly desires you to invite Hector to his tent,--  

**THERSITES**  
Hum!  

**PATROCLUS**  
And to procure safe-conduct from Agamemnon.  

**THERSITES**  
Agamemnon!  

**PATROCLUS**  
Ay, my lord.  

**THERSITES**  
Ha!  

**PATROCLUS**  
What say you to't?  

**THERSITES**  
God b' wi' you, with all my heart.  

**PATROCLUS**  
Your answer, sir.  

**THERSITES**  
If to-morrow be a fair day, by eleven o'clock it will  
go one way or other: howsoever, he shall pay for me  
ere he has me.  

**PATROCLUS**  
Your answer, sir.  

**THERSITES**  
Fare you well, with all my heart.  

**ACHILLES**  
Why, but he is not in this tune, is he?  

**THERSITES**  
No, but he's out o' tune thus. What music will be in  
him when Hector has knocked out his brains, I know  
not; but, I am sure, none, unless the fiddler Apollo  
get his sinews to make catlings on.  

**ACHILLES**  
Come, thou shalt bear a letter to him straight.  

**THERSITES**  
Let me bear another to his horse; for that's the more  
capable creature.  

**ACHILLES**  
My mind is troubled, like a fountain stirr'd;  
And I myself see not the bottom of it.  

_Exeunt ACHILLES and PATROCLUS_

**THERSITES**  
Would the fountain of your mind were clear again,  
that I might water an ass at it! I had rather be a  
tick in a sheep than such a valiant ignorance.  

_Exit_

# ACT IV

### SCENE I. Troy. A street.

_Enter, from one side, AENEAS, and Servant with a torch; from the other,
PARIS, DEIPHOBUS, ANTENOR, DIOMEDES, and others, with torches_

**PARIS**  
See, ho! who is that there?  

**DEIPHOBUS**  
It is the Lord AEneas.  

**AENEAS**  
Is the prince there in person?  
Had I so good occasion to lie long  
As you, prince Paris, nothing but heavenly business  
Should rob my bed-mate of my company.  

**DIOMEDES**  
That's my mind too. Good morrow, Lord AEneas.  

**PARIS**  
A valiant Greek, AEneas,--take his hand,--  
Witness the process of your speech, wherein  
You told how Diomed, a whole week by days,  
Did haunt you in the field.  

**AENEAS**  
Health to you, valiant sir,  
During all question of the gentle truce;  
But when I meet you arm'd, as black defiance  
As heart can think or courage execute.  

**DIOMEDES**  
The one and other Diomed embraces.  
Our bloods are now in calm; and, so long, health!  
But when contention and occasion meet,  
By Jove, I'll play the hunter for thy life  
With all my force, pursuit and policy.  

**AENEAS**  
And thou shalt hunt a lion, that will fly  
With his face backward. In humane gentleness,  
Welcome to Troy! now, by Anchises' life,  
Welcome, indeed! By Venus' hand I swear,  
No man alive can love in such a sort  
The thing he means to kill more excellently.  

**DIOMEDES**  
We sympathize: Jove, let AEneas live,  
If to my sword his fate be not the glory,  
A thousand complete courses of the sun!  
But, in mine emulous honour, let him die,  
With every joint a wound, and that to-morrow!  

**AENEAS**  
We know each other well.  

**DIOMEDES**  
We do; and long to know each other worse.  

**PARIS**  
This is the most despiteful gentle greeting,  
The noblest hateful love, that e'er I heard of.  
What business, lord, so early?  

**AENEAS**  
I was sent for to the king; but why, I know not.  

**PARIS**  
His purpose meets you: 'twas to bring this Greek  
To Calchas' house, and there to render him,  
For the enfreed Antenor, the fair Cressid:  
Let's have your company, or, if you please,  
Haste there before us: I constantly do think--  
Or rather, call my thought a certain knowledge--  
My brother Troilus lodges there to-night:  
Rouse him and give him note of our approach.  
With the whole quality wherefore: I fear  
We shall be much unwelcome.  

**AENEAS**  
That I assure you:  
Troilus had rather Troy were borne to Greece  
Than Cressid borne from Troy.  

**PARIS**  
There is no help;  
The bitter disposition of the time  
Will have it so. On, lord; we'll follow you.  

**AENEAS**  
Good morrow, all.  

_Exit with Servant_

**PARIS**  
And tell me, noble Diomed, faith, tell me true,  
Even in the soul of sound good-fellowship,  
Who, in your thoughts, merits fair Helen best,  
Myself or Menelaus?  

**DIOMEDES**  
Both alike:  
He merits well to have her, that doth seek her,  
Not making any scruple of her soilure,  
With such a hell of pain and world of charge,  
And you as well to keep her, that defend her,  
Not palating the taste of her dishonour,  
With such a costly loss of wealth and friends:  
He, like a puling cuckold, would drink up  
The lees and dregs of a flat tamed piece;  
You, like a lecher, out of whorish loins  
Are pleased to breed out your inheritors:  
Both merits poised, each weighs nor less nor more;  
But he as he, the heavier for a whore.  

**PARIS**  
You are too bitter to your countrywoman.  

**DIOMEDES**  
She's bitter to her country: hear me, Paris:  
For every false drop in her bawdy veins  
A Grecian's life hath sunk; for every scruple  
Of her contaminated carrion weight,  
A Trojan hath been slain: since she could speak,  
She hath not given so many good words breath  
As for her Greeks and Trojans suffer'd death.  

**PARIS**  
Fair Diomed, you do as chapmen do,  
Dispraise the thing that you desire to buy:  
But we in silence hold this virtue well,  
We'll but commend what we intend to sell.  
Here lies our way.  

_Exeunt_

### SCENE II. The same. Court of Pandarus' house.

_Enter TROILUS and CRESSIDA_

**TROILUS**  
Dear, trouble not yourself: the morn is cold.  

**CRESSIDA**  
Then, sweet my lord, I'll call mine uncle down;  
He shall unbolt the gates.  

**TROILUS**  
Trouble him not;  
To bed, to bed: sleep kill those pretty eyes,  
And give as soft attachment to thy senses  
As infants' empty of all thought!  

**CRESSIDA**  
Good morrow, then.  

**TROILUS**  
I prithee now, to bed.  

**CRESSIDA**  
Are you a-weary of me?  

**TROILUS**  
O Cressida! but that the busy day,  
Waked by the lark, hath roused the ribald crows,  
And dreaming night will hide our joys no longer,  
I would not from thee.  

**CRESSIDA**  
Night hath been too brief.  

**TROILUS**  
Beshrew the witch! with venomous wights she stays  
As tediously as hell, but flies the grasps of love  
With wings more momentary-swift than thought.  
You will catch cold, and curse me.  

**CRESSIDA**  
Prithee, tarry:  
You men will never tarry.  
O foolish Cressid! I might have still held off,  
And then you would have tarried. Hark!  
there's one up.  

**PANDARUS**  
_[Within]_  
What, 's all the doors open here?  

**TROILUS**  
It is your uncle.  

**CRESSIDA**  
A pestilence on him! now will he be mocking:  
I shall have such a life!  

_Enter PANDARUS_

**PANDARUS**  
How now, how now! how go maidenheads? Here, you  
maid! where's my cousin Cressid?  

**CRESSIDA**  
Go hang yourself, you naughty mocking uncle!  
You bring me to do, and then you flout me too.  

**PANDARUS**  
To do what? to do what? let her say  
what: what have I brought you to do?  

**CRESSIDA**  
Come, come, beshrew your heart! you'll ne'er be good,  
Nor suffer others.  

**PANDARUS**  
Ha! ha! Alas, poor wretch! ah, poor capocchia!  
hast not slept to-night? would he not, a naughty  
man, let it sleep? a bugbear take him!  

**CRESSIDA**  
Did not I tell you? Would he were knock'd i' the head!  

_Knocking within_

Who's that at door? good uncle, go and see.  
My lord, come you again into my chamber:  
You smile and mock me, as if I meant naughtily.  

**TROILUS**  
Ha, ha!  

**CRESSIDA**  
Come, you are deceived, I think of no such thing.  

_Knocking within_

How earnestly they knock! Pray you, come in:  
I would not for half Troy have you seen here.  

_Exeunt TROILUS and CRESSIDA_

**PANDARUS**  
Who's there? what's the matter? will you beat  
down the door? How now! what's the matter?  

_Enter AENEAS_

**AENEAS**  
Good morrow, lord, good morrow.  

**PANDARUS**  
Who's there? my Lord AEneas! By my troth,  
I knew you not: what news with you so early?  

**AENEAS**  
Is not Prince Troilus here?  

**PANDARUS**  
Here! what should he do here?  

**AENEAS**  
Come, he is here, my lord; do not deny him:  
It doth import him much to speak with me.  

**PANDARUS**  
Is he here, say you? 'tis more than I know, I'll  
be sworn: for my own part, I came in late. What  
should he do here?  

**AENEAS**  
Who!--nay, then: come, come, you'll do him wrong  
ere you're ware: you'll be so true to him, to be  
false to him: do not you know of him, but yet go  
fetch him hither; go.  

_Re-enter TROILUS_

**TROILUS**  
How now! what's the matter?  

**AENEAS**  
My lord, I scarce have leisure to salute you,  
My matter is so rash: there is at hand  
Paris your brother, and Deiphobus,  
The Grecian Diomed, and our Antenor  
Deliver'd to us; and for him forthwith,  
Ere the first sacrifice, within this hour,  
We must give up to Diomedes' hand  
The Lady Cressida.  

**TROILUS**  
Is it so concluded?  

**AENEAS**  
By Priam and the general state of Troy:  
They are at hand and ready to effect it.  

**TROILUS**  
How my achievements mock me!  
I will go meet them: and, my Lord AEneas,  
We met by chance; you did not find me here.  

**AENEAS**  
Good, good, my lord; the secrets of nature  
Have not more gift in taciturnity.  

_Exeunt TROILUS and AENEAS_

**PANDARUS**  
Is't possible? no sooner got but lost? The devil  
take Antenor! the young prince will go mad: a  
plague upon Antenor! I would they had broke 's neck!  

_Re-enter CRESSIDA_

**CRESSIDA**  
How now! what's the matter? who was here?  

**PANDARUS**  
Ah, ah!  

**CRESSIDA**  
Why sigh you so profoundly? where's my lord? gone!  
Tell me, sweet uncle, what's the matter?  

**PANDARUS**  
Would I were as deep under the earth as I am above!  

**CRESSIDA**  
O the gods! what's the matter?  

**PANDARUS**  
Prithee, get thee in: would thou hadst ne'er been  
born! I knew thou wouldst be his death. O, poor  
gentleman! A plague upon Antenor!  

**CRESSIDA**  
Good uncle, I beseech you, on my knees! beseech you,  
what's the matter?  

**PANDARUS**  
Thou must be gone, wench, thou must be gone; thou  
art changed for Antenor: thou must to thy father,  
and be gone from Troilus: 'twill be his death;  
'twill be his bane; he cannot bear it.  

**CRESSIDA**  
O you immortal gods! I will not go.  

**PANDARUS**  
Thou must.  

**CRESSIDA**  
I will not, uncle: I have forgot my father;  
I know no touch of consanguinity;  
No kin no love, no blood, no soul so near me  
As the sweet Troilus. O you gods divine!  
Make Cressid's name the very crown of falsehood,  
If ever she leave Troilus! Time, force, and death,  
Do to this body what extremes you can;  
But the strong base and building of my love  
Is as the very centre of the earth,  
Drawing all things to it. I'll go in and weep,--  

**PANDARUS**  
Do, do.  

**CRESSIDA**  
Tear my bright hair and scratch my praised cheeks,  
Crack my clear voice with sobs and break my heart  
With sounding Troilus. I will not go from Troy.  

_Exeunt_

### SCENE III. The same. Street before Pandarus' house.

_Enter PARIS, TROILUS, AENEAS, DEIPHOBUS, ANTENOR, and DIOMEDES_

**PARIS**  
It is great morning, and the hour prefix'd  
Of her delivery to this valiant Greek  
Comes fast upon. Good my brother Troilus,  
Tell you the lady what she is to do,  
And haste her to the purpose.  

**TROILUS**  
Walk into her house;  
I'll bring her to the Grecian presently:  
And to his hand when I deliver her,  
Think it an altar, and thy brother Troilus  
A priest there offering to it his own heart.  

_Exit_

**PARIS**  
I know what 'tis to love;  
And would, as I shall pity, I could help!  
Please you walk in, my lords.  

_Exeunt_

### SCENE IV. The same. Pandarus' house.

_Enter PANDARUS and CRESSIDA_

**PANDARUS**  
Be moderate, be moderate.  

**CRESSIDA**  
Why tell you me of moderation?  
The grief is fine, full, perfect, that I taste,  
And violenteth in a sense as strong  
As that which causeth it: how can I moderate it?  
If I could temporize with my affection,  
Or brew it to a weak and colder palate,  
The like allayment could I give my grief.  
My love admits no qualifying dross;  
No more my grief, in such a precious loss.  

**PANDARUS**  
Here, here, here he comes.  

_Enter TROILUS_

Ah, sweet ducks!  

**CRESSIDA**  
O Troilus! Troilus!  

_Embracing him_

**PANDARUS**  
What a pair of spectacles is here!  
Let me embrace too. 'O heart,' as the goodly saying is,  
'\--O heart, heavy heart,  
Why sigh'st thou without breaking?  
where he answers again,  
'Because thou canst not ease thy smart  
By friendship nor by speaking.'  
There was never a truer rhyme. Let us cast away  
nothing, for we may live to have need of such a  
verse: we see it, we see it. How now, lambs?  

**TROILUS**  
Cressid, I love thee in so strain'd a purity,  
That the bless'd gods, as angry with my fancy,  
More bright in zeal than the devotion which  
Cold lips blow to their deities, take thee from me.  

**CRESSIDA**  
Have the gods envy?  

**PANDARUS**  
Ay, ay, ay, ay; 'tis too plain a case.  

**CRESSIDA**  
And is it true that I must go from Troy?  

**TROILUS**  
A hateful truth.  

**CRESSIDA**  
What, and from Troilus too?  

**TROILUS**  
From Troy and Troilus.  

**CRESSIDA**  
Is it possible?  

**TROILUS**  
And suddenly; where injury of chance  
Puts back leave-taking, justles roughly by  
All time of pause, rudely beguiles our lips  
Of all rejoindure, forcibly prevents  
Our lock'd embrasures, strangles our dear vows  
Even in the birth of our own labouring breath:  
We two, that with so many thousand sighs  
Did buy each other, must poorly sell ourselves  
With the rude brevity and discharge of one.  
Injurious time now with a robber's haste  
Crams his rich thievery up, he knows not how:  
As many farewells as be stars in heaven,  
With distinct breath and consign'd kisses to them,  
He fumbles up into a lose adieu,  
And scants us with a single famish'd kiss,  
Distasted with the salt of broken tears.  

**AENEAS**  
_[Within]_  
My lord, is the lady ready?  

**TROILUS**  
Hark! you are call'd: some say the Genius so  
Cries 'come' to him that instantly must die.  
Bid them have patience; she shall come anon.  

**PANDARUS**  
Where are my tears? rain, to lay this wind, or  
my heart will be blown up by the root.  

_Exit_

**CRESSIDA**  
I must then to the Grecians?  

**TROILUS**  
No remedy.  

**CRESSIDA**  
A woful Cressid 'mongst the merry Greeks!  
When shall we see again?  

**TROILUS**  
Hear me, my love: be thou but true of heart,--  

**CRESSIDA**  
I true! how now! what wicked deem is this?  

**TROILUS**  
Nay, we must use expostulation kindly,  
For it is parting from us:  
I speak not 'be thou true,' as fearing thee,  
For I will throw my glove to Death himself,  
That there's no maculation in thy heart:  
But 'be thou true,' say I, to fashion in  
My sequent protestation; be thou true,  
And I will see thee.  

**CRESSIDA**  
O, you shall be exposed, my lord, to dangers  
As infinite as imminent! but I'll be true.  

**TROILUS**  
And I'll grow friend with danger. Wear this sleeve.  

**CRESSIDA**  
And you this glove. When shall I see you?  

**TROILUS**  
I will corrupt the Grecian sentinels,  
To give thee nightly visitation.  
But yet be true.  

**CRESSIDA**  
O heavens! 'be true' again!  

**TROILUS**  
Hear while I speak it, love:  
The Grecian youths are full of quality;  
They're loving, well composed with gifts of nature,  
Flowing and swelling o'er with arts and exercise:  
How novelty may move, and parts with person,  
Alas, a kind of godly jealousy--  
Which, I beseech you, call a virtuous sin--  
Makes me afeard.  

**CRESSIDA**  
O heavens! you love me not.  

**TROILUS**  
Die I a villain, then!  
In this I do not call your faith in question  
So mainly as my merit: I cannot sing,  
Nor heel the high lavolt, nor sweeten talk,  
Nor play at subtle games; fair virtues all,  
To which the Grecians are most prompt and pregnant:  
But I can tell that in each grace of these  
There lurks a still and dumb-discoursive devil  
That tempts most cunningly: but be not tempted.  

**CRESSIDA**  
Do you think I will?  

**TROILUS**  
No.  
But something may be done that we will not:  
And sometimes we are devils to ourselves,  
When we will tempt the frailty of our powers,  
Presuming on their changeful potency.  

**AENEAS**  
_[Within]_  
Nay, good my lord,--  

**TROILUS**  
Come, kiss; and let us part.  

**PARIS**  
_[Within]_  
Brother Troilus!  

**TROILUS**  
Good brother, come you hither;  
And bring AEneas and the Grecian with you.  

**CRESSIDA**  
My lord, will you be true?  

**TROILUS**  
Who, I? alas, it is my vice, my fault:  
Whiles others fish with craft for great opinion,  
I with great truth catch mere simplicity;  
Whilst some with cunning gild their copper crowns,  
With truth and plainness I do wear mine bare.  
Fear not my truth: the moral of my wit  
Is 'plain and true;' there's all the reach of it.  

_Enter AENEAS, PARIS, ANTENOR, DEIPHOBUS, and DIOMEDES_

Welcome, Sir Diomed! here is the lady  
Which for Antenor we deliver you:  
At the port, lord, I'll give her to thy hand,  
And by the way possess thee what she is.  
Entreat her fair; and, by my soul, fair Greek,  
If e'er thou stand at mercy of my sword,  
Name Cressida and thy life shall be as safe  
As Priam is in Ilion.  

**DIOMEDES**  
Fair Lady Cressid,  
So please you, save the thanks this prince expects:  
The lustre in your eye, heaven in your cheek,  
Pleads your fair usage; and to Diomed  
You shall be mistress, and command him wholly.  

**TROILUS**  
Grecian, thou dost not use me courteously,  
To shame the zeal of my petition to thee  
In praising her: I tell thee, lord of Greece,  
She is as far high-soaring o'er thy praises  
As thou unworthy to be call'd her servant.  
I charge thee use her well, even for my charge;  
For, by the dreadful Pluto, if thou dost not,  
Though the great bulk Achilles be thy guard,  
I'll cut thy throat.  

**DIOMEDES**  
O, be not moved, Prince Troilus:  
Let me be privileged by my place and message,  
To be a speaker free; when I am hence  
I'll answer to my lust: and know you, lord,  
I'll nothing do on charge: to her own worth  
She shall be prized; but that you say 'be't so,'  
I'll speak it in my spirit and honour, 'no.'  

**TROILUS**  
Come, to the port. I'll tell thee, Diomed,  
This brave shall oft make thee to hide thy head.  
Lady, give me your hand, and, as we walk,  
To our own selves bend we our needful talk.  

_Exeunt TROILUS, CRESSIDA, and DIOMEDES_

_Trumpet within_

**PARIS**  
Hark! Hector's trumpet.  

**AENEAS**  
How have we spent this morning!  
The prince must think me tardy and remiss,  
That sore to ride before him to the field.  

**PARIS**  
'Tis Troilus' fault: come, come, to field with him.  

**DEIPHOBUS**  
Let us make ready straight.  

**AENEAS**  
Yea, with a bridegroom's fresh alacrity,  
Let us address to tend on Hector's heels:  
The glory of our Troy doth this day lie  
On his fair worth and single chivalry.  

_Exeunt_

### SCENE V. The Grecian camp. Lists set out.

_Enter AJAX, armed; AGAMEMNON, ACHILLES, PATROCLUS, MENELAUS, ULYSSES,
NESTOR, and others_

**AGAMEMNON**  
Here art thou in appointment fresh and fair,  
Anticipating time with starting courage.  
Give with thy trumpet a loud note to Troy,  
Thou dreadful Ajax; that the appalled air  
May pierce the head of the great combatant  
And hale him hither.  

**AJAX**  
Thou, trumpet, there's my purse.  
Now crack thy lungs, and split thy brazen pipe:  
Blow, villain, till thy sphered bias cheek  
Outswell the colic of puff'd Aquilon:  
Come, stretch thy chest and let thy eyes spout blood;  
Thou blow'st for Hector.  

_Trumpet sounds_

**ULYSSES**  
No trumpet answers.  

**ACHILLES**  
'Tis but early days.  

**AGAMEMNON**  
Is not yond Diomed, with Calchas' daughter?  

**ULYSSES**  
'Tis he, I ken the manner of his gait;  
He rises on the toe: that spirit of his  
In aspiration lifts him from the earth.  

_Enter DIOMEDES, with CRESSIDA_

**AGAMEMNON**  
Is this the Lady Cressid?  

**DIOMEDES**  
Even she.  

**AGAMEMNON**  
Most dearly welcome to the Greeks, sweet lady.  

**NESTOR**  
Our general doth salute you with a kiss.  

**ULYSSES**  
Yet is the kindness but particular;  
'Twere better she were kiss'd in general.  

**NESTOR**  
And very courtly counsel: I'll begin.  
So much for Nestor.  

**ACHILLES**  
I'll take what winter from your lips, fair lady:  
Achilles bids you welcome.  

**MENELAUS**  
I had good argument for kissing once.  

**PATROCLUS**  
But that's no argument for kissing now;  
For this popp'd Paris in his hardiment,  
And parted thus you and your argument.  

**ULYSSES**  
O deadly gall, and theme of all our scorns!  
For which we lose our heads to gild his horns.  

**PATROCLUS**  
The first was Menelaus' kiss; this, mine:  
Patroclus kisses you.  

**MENELAUS**  
O, this is trim!  

**PATROCLUS**  
Paris and I kiss evermore for him.  

**MENELAUS**  
I'll have my kiss, sir. Lady, by your leave.  

**CRESSIDA**  
In kissing, do you render or receive?  

**PATROCLUS**  
Both take and give.  

**CRESSIDA**  
I'll make my match to live,  
The kiss you take is better than you give;  
Therefore no kiss.  

**MENELAUS**  
I'll give you boot, I'll give you three for one.  

**CRESSIDA**  
You're an odd man; give even or give none.  

**MENELAUS**  
An odd man, lady! every man is odd.  

**CRESSIDA**  
No, Paris is not; for you know 'tis true,  
That you are odd, and he is even with you.  

**MENELAUS**  
You fillip me o' the head.  

**CRESSIDA**  
No, I'll be sworn.  

**ULYSSES**  
It were no match, your nail against his horn.  
May I, sweet lady, beg a kiss of you?  

**CRESSIDA**  
You may.  

**ULYSSES**  
I do desire it.  

**CRESSIDA**  
Why, beg, then.  

**ULYSSES**  
Why then for Venus' sake, give me a kiss,  
When Helen is a maid again, and his.  

**CRESSIDA**  
I am your debtor, claim it when 'tis due.  

**ULYSSES**  
Never's my day, and then a kiss of you.  

**DIOMEDES**  
Lady, a word: I'll bring you to your father.  

_Exit with CRESSIDA_

**NESTOR**  
A woman of quick sense.  

**ULYSSES**  
Fie, fie upon her!  
There's language in her eye, her cheek, her lip,  
Nay, her foot speaks; her wanton spirits look out  
At every joint and motive of her body.  
O, these encounterers, so glib of tongue,  
That give accosting welcome ere it comes,  
And wide unclasp the tables of their thoughts  
To every ticklish reader! set them down  
For sluttish spoils of opportunity  
And daughters of the game.  

_Trumpet within_

**ALL**  
The Trojans' trumpet.  

**AGAMEMNON**  
Yonder comes the troop.  

_Enter HECTOR, armed; AENEAS, TROILUS, and other Trojans, with Attendants_

**AENEAS**  
Hail, all you state of Greece! what shall be done  
To him that victory commands? or do you purpose  
A victor shall be known? will you the knights  
Shall to the edge of all extremity  
Pursue each other, or shall be divided  
By any voice or order of the field?  
Hector bade ask.  

**AGAMEMNON**  
Which way would Hector have it?  

**AENEAS**  
He cares not; he'll obey conditions.  

**ACHILLES**  
'Tis done like Hector; but securely done,  
A little proudly, and great deal misprizing  
The knight opposed.  

**AENEAS**  
If not Achilles, sir,  
What is your name?  

**ACHILLES**  
If not Achilles, nothing.  

**AENEAS**  
Therefore Achilles: but, whate'er, know this:  
In the extremity of great and little,  
Valour and pride excel themselves in Hector;  
The one almost as infinite as all,  
The other blank as nothing. Weigh him well,  
And that which looks like pride is courtesy.  
This Ajax is half made of Hector's blood:  
In love whereof, half Hector stays at home;  
Half heart, half hand, half Hector comes to seek  
This blended knight, half Trojan and half Greek.  

**ACHILLES**  
A maiden battle, then? O, I perceive you.  

_Re-enter DIOMEDES_

**AGAMEMNON**  
Here is Sir Diomed. Go, gentle knight,  
Stand by our Ajax: as you and Lord AEneas  
Consent upon the order of their fight,  
So be it; either to the uttermost,  
Or else a breath: the combatants being kin  
Half stints their strife before their strokes begin.  

_AJAX and HECTOR enter the lists_

**ULYSSES**  
They are opposed already.  

**AGAMEMNON**  
What Trojan is that same that looks so heavy?  

**ULYSSES**  
The youngest son of Priam, a true knight,  
Not yet mature, yet matchless, firm of word,  
Speaking in deeds and deedless in his tongue;  
Not soon provoked nor being provoked soon calm'd:  
His heart and hand both open and both free;  
For what he has he gives, what thinks he shows;  
Yet gives he not till judgment guide his bounty,  
Nor dignifies an impure thought with breath;  
Manly as Hector, but more dangerous;  
For Hector in his blaze of wrath subscribes  
To tender objects, but he in heat of action  
Is more vindicative than jealous love:  
They call him Troilus, and on him erect  
A second hope, as fairly built as Hector.  
Thus says AEneas; one that knows the youth  
Even to his inches, and with private soul  
Did in great Ilion thus translate him to me.  

_Alarum. Hector and Ajax fight_

**AGAMEMNON**  
They are in action.  

**NESTOR**  
Now, Ajax, hold thine own!  

**TROILUS**  
Hector, thou sleep'st;  
Awake thee!  

**AGAMEMNON**  
His blows are well disposed: there, Ajax!  

**DIOMEDES**  
You must no more.  

_Trumpets cease_

**AENEAS**  
Princes, enough, so please you.  

**AJAX**  
I am not warm yet; let us fight again.  

**DIOMEDES**  
As Hector pleases.  

**HECTOR**  
Why, then will I no more:  
Thou art, great lord, my father's sister's son,  
A cousin-german to great Priam's seed;  
The obligation of our blood forbids  
A gory emulation 'twixt us twain:  
Were thy commixtion Greek and Trojan so  
That thou couldst say 'This hand is Grecian all,  
And this is Trojan; the sinews of this leg  
All Greek, and this all Troy; my mother's blood  
Runs on the dexter cheek, and this sinister  
Bounds in my father's;' by Jove multipotent,  
Thou shouldst not bear from me a Greekish member  
Wherein my sword had not impressure made  
Of our rank feud: but the just gods gainsay  
That any drop thou borrow'dst from thy mother,  
My sacred aunt, should by my mortal sword  
Be drain'd! Let me embrace thee, Ajax:  
By him that thunders, thou hast lusty arms;  
Hector would have them fall upon him thus:  
Cousin, all honour to thee!  

**AJAX**  
I thank thee, Hector  
Thou art too gentle and too free a man:  
I came to kill thee, cousin, and bear hence  
A great addition earned in thy death.  

**HECTOR**  
Not Neoptolemus so mirable,  
On whose bright crest Fame with her loud'st Oyes  
Cries 'This is he,' could promise to himself  
A thought of added honour torn from Hector.  

**AENEAS**  
There is expectance here from both the sides,  
What further you will do.  

**HECTOR**  
We'll answer it;  
The issue is embracement: Ajax, farewell.  

**AJAX**  
If I might in entreaties find success--  
As seld I have the chance--I would desire  
My famous cousin to our Grecian tents.  

**DIOMEDES**  
'Tis Agamemnon's wish, and great Achilles  
Doth long to see unarm'd the valiant Hector.  

**HECTOR**  
AEneas, call my brother Troilus to me,  
And signify this loving interview  
To the expecters of our Trojan part;  
Desire them home. Give me thy hand, my cousin;  
I will go eat with thee and see your knights.  

**AJAX**  
Great Agamemnon comes to meet us here.  

**HECTOR**  
The worthiest of them tell me name by name;  
But for Achilles, mine own searching eyes  
Shall find him by his large and portly size.  

**AGAMEMNON**  
Worthy of arms! as welcome as to one  
That would be rid of such an enemy;  
But that's no welcome: understand more clear,  
What's past and what's to come is strew'd with husks  
And formless ruin of oblivion;  
But in this extant moment, faith and troth,  
Strain'd purely from all hollow bias-drawing,  
Bids thee, with most divine integrity,  
From heart of very heart, great Hector, welcome.  

**HECTOR**  
I thank thee, most imperious Agamemnon.  

**AGAMEMNON**  
_[To TROILUS]_  
My well-famed lord of Troy, no  
less to you.  

**MENELAUS**  
Let me confirm my princely brother's greeting:  
You brace of warlike brothers, welcome hither.  

**HECTOR**  
Who must we answer?  

**AENEAS**  
The noble Menelaus.  

**HECTOR**  
O, you, my lord? by Mars his gauntlet, thanks!  
Mock not, that I affect the untraded oath;  
Your quondam wife swears still by Venus' glove:  
She's well, but bade me not commend her to you.  

**MENELAUS**  
Name her not now, sir; she's a deadly theme.  

**HECTOR**  
O, pardon; I offend.  

**NESTOR**  
I have, thou gallant Trojan, seen thee oft  
Labouring for destiny make cruel way  
Through ranks of Greekish youth, and I have seen thee,  
As hot as Perseus, spur thy Phrygian steed,  
Despising many forfeits and subduements,  
When thou hast hung thy advanced sword i' the air,  
Not letting it decline on the declined,  
That I have said to some my standers by  
'Lo, Jupiter is yonder, dealing life!'  
And I have seen thee pause and take thy breath,  
When that a ring of Greeks have hemm'd thee in,  
Like an Olympian wrestling: this have I seen;  
But this thy countenance, still lock'd in steel,  
I never saw till now. I knew thy grandsire,  
And once fought with him: he was a soldier good;  
But, by great Mars, the captain of us all,  
Never saw like thee. Let an old man embrace thee;  
And, worthy warrior, welcome to our tents.  

**AENEAS**  
'Tis the old Nestor.  

**HECTOR**  
Let me embrace thee, good old chronicle,  
That hast so long walk'd hand in hand with time:  
Most reverend Nestor, I am glad to clasp thee.  

**NESTOR**  
I would my arms could match thee in contention,  
As they contend with thee in courtesy.  

**HECTOR**  
I would they could.  

**NESTOR**  
Ha!  
By this white beard, I'ld fight with thee to-morrow.  
Well, welcome, welcome! I have seen the time.  

**ULYSSES**  
I wonder now how yonder city stands  
When we have here her base and pillar by us.  

**HECTOR**  
I know your favour, Lord Ulysses, well.  
Ah, sir, there's many a Greek and Trojan dead,  
Since first I saw yourself and Diomed  
In Ilion, on your Greekish embassy.  

**ULYSSES**  
Sir, I foretold you then what would ensue:  
My prophecy is but half his journey yet;  
For yonder walls, that pertly front your town,  
Yond towers, whose wanton tops do buss the clouds,  
Must kiss their own feet.  

**HECTOR**  
I must not believe you:  
There they stand yet, and modestly I think,  
The fall of every Phrygian stone will cost  
A drop of Grecian blood: the end crowns all,  
And that old common arbitrator, Time,  
Will one day end it.  

**ULYSSES**  
So to him we leave it.  
Most gentle and most valiant Hector, welcome:  
After the general, I beseech you next  
To feast with me and see me at my tent.  

**ACHILLES**  
I shall forestall thee, Lord Ulysses, thou!  
Now, Hector, I have fed mine eyes on thee;  
I have with exact view perused thee, Hector,  
And quoted joint by joint.  

**HECTOR**  
Is this Achilles?  

**ACHILLES**  
I am Achilles.  

**HECTOR**  
Stand fair, I pray thee: let me look on thee.  

**ACHILLES**  
Behold thy fill.  

**HECTOR**  
Nay, I have done already.  

**ACHILLES**  
Thou art too brief: I will the second time,  
As I would buy thee, view thee limb by limb.  

**HECTOR**  
O, like a book of sport thou'lt read me o'er;  
But there's more in me than thou understand'st.  
Why dost thou so oppress me with thine eye?  

**ACHILLES**  
Tell me, you heavens, in which part of his body  
Shall I destroy him? whether there, or there, or there?  
That I may give the local wound a name  
And make distinct the very breach whereout  
Hector's great spirit flew: answer me, heavens!  

**HECTOR**  
It would discredit the blest gods, proud man,  
To answer such a question: stand again:  
Think'st thou to catch my life so pleasantly  
As to prenominate in nice conjecture  
Where thou wilt hit me dead?  

**ACHILLES**  
I tell thee, yea.  

**HECTOR**  
Wert thou an oracle to tell me so,  
I'd not believe thee. Henceforth guard thee well;  
For I'll not kill thee there, nor there, nor there;  
But, by the forge that stithied Mars his helm,  
I'll kill thee every where, yea, o'er and o'er.  
You wisest Grecians, pardon me this brag;  
His insolence draws folly from my lips;  
But I'll endeavour deeds to match these words,  
Or may I never--  

**AJAX**  
Do not chafe thee, cousin:  
And you, Achilles, let these threats alone,  
Till accident or purpose bring you to't:  
You may have every day enough of Hector  
If you have stomach; the general state, I fear,  
Can scarce entreat you to be odd with him.  

**HECTOR**  
I pray you, let us see you in the field:  
We have had pelting wars, since you refused  
The Grecians' cause.  

**ACHILLES**  
Dost thou entreat me, Hector?  
To-morrow do I meet thee, fell as death;  
To-night all friends.  

**HECTOR**  
Thy hand upon that match.  

**AGAMEMNON**  
First, all you peers of Greece, go to my tent;  
There in the full convive we: afterwards,  
As Hector's leisure and your bounties shall  
Concur together, severally entreat him.  
Beat loud the tabourines, let the trumpets blow,  
That this great soldier may his welcome know.  

_Exeunt all except TROILUS and ULYSSES_

**TROILUS**  
My Lord Ulysses, tell me, I beseech you,  
In what place of the field doth Calchas keep?  

**ULYSSES**  
At Menelaus' tent, most princely Troilus:  
There Diomed doth feast with him to-night;  
Who neither looks upon the heaven nor earth,  
But gives all gaze and bent of amorous view  
On the fair Cressid.  

**TROILUS**  
Shall sweet lord, be bound to you so much,  
After we part from Agamemnon's tent,  
To bring me thither?  

**ULYSSES**  
You shall command me, sir.  
As gentle tell me, of what honour was  
This Cressida in Troy? Had she no lover there  
That wails her absence?  

**TROILUS**  
O, sir, to such as boasting show their scars  
A mock is due. Will you walk on, my lord?  
She was beloved, she loved; she is, and doth:  
But still sweet love is food for fortune's tooth.  

_Exeunt_

# ACT V

### SCENE I. The Grecian camp. Before Achilles' tent.

_Enter ACHILLES and PATROCLUS_

**ACHILLES**  
I'll heat his blood with Greekish wine to-night,  
Which with my scimitar I'll cool to-morrow.  
Patroclus, let us feast him to the height.  

**PATROCLUS**  
Here comes Thersites.  

_Enter THERSITES_

**ACHILLES**  
How now, thou core of envy!  
Thou crusty batch of nature, what's the news?  

**THERSITES**  
Why, thou picture of what thou seemest, and idol  
of idiot worshippers, here's a letter for thee.  

**ACHILLES**  
From whence, fragment?  

**THERSITES**  
Why, thou full dish of fool, from Troy.  

**PATROCLUS**  
Who keeps the tent now?  

**THERSITES**  
The surgeon's box, or the patient's wound.  

**PATROCLUS**  
Well said, adversity! and what need these tricks?  

**THERSITES**  
Prithee, be silent, boy; I profit not by thy talk:  
thou art thought to be Achilles' male varlet.  

**PATROCLUS**  
Male varlet, you rogue! what's that?  

**THERSITES**  
Why, his masculine whore. Now, the rotten diseases  
of the south, the guts-griping, ruptures, catarrhs,  
loads o' gravel i' the back, lethargies, cold  
palsies, raw eyes, dirt-rotten livers, wheezing  
lungs, bladders full of imposthume, sciaticas,  
limekilns i' the palm, incurable bone-ache, and the  
rivelled fee-simple of the tetter, take and take  
again such preposterous discoveries!  

**PATROCLUS**  
Why thou damnable box of envy, thou, what meanest  
thou to curse thus?  

**THERSITES**  
Do I curse thee?  

**PATROCLUS**  
Why no, you ruinous butt, you whoreson  
indistinguishable cur, no.  

**THERSITES**  
No! why art thou then exasperate, thou idle  
immaterial skein of sleave-silk, thou green sarcenet  
flap for a sore eye, thou tassel of a prodigal's  
purse, thou? Ah, how the poor world is pestered  
with such waterflies, diminutives of nature!  

**PATROCLUS**  
Out, gall!  

**THERSITES**  
Finch-egg!  

**ACHILLES**  
My sweet Patroclus, I am thwarted quite  
From my great purpose in to-morrow's battle.  
Here is a letter from Queen Hecuba,  
A token from her daughter, my fair love,  
Both taxing me and gaging me to keep  
An oath that I have sworn. I will not break it:  
Fall Greeks; fail fame; honour or go or stay;  
My major vow lies here, this I'll obey.  
Come, come, Thersites, help to trim my tent:  
This night in banqueting must all be spent.  
Away, Patroclus!  

_Exeunt ACHILLES and PATROCLUS_

**THERSITES**  
With too much blood and too little brain, these two  
may run mad; but, if with too much brain and too  
little blood they do, I'll be a curer of madmen.  
Here's Agamemnon, an honest fellow enough and one  
that loves quails; but he has not so much brain as  
earwax: and the goodly transformation of Jupiter  
there, his brother, the bull,--the primitive statue,  
and oblique memorial of cuckolds; a thrifty  
shoeing-horn in a chain, hanging at his brother's  
leg,--to what form but that he is, should wit larded  
with malice and malice forced with wit turn him to?  
To an ass, were nothing; he is both ass and ox: to  
an ox, were nothing; he is both ox and ass. To be a  
dog, a mule, a cat, a fitchew, a toad, a lizard, an  
owl, a puttock, or a herring without a roe, I would  
not care; but to be Menelaus, I would conspire  
against destiny. Ask me not, what I would be, if I  
were not Thersites; for I care not to be the louse  
of a lazar, so I were not Menelaus! Hey-day!  
spirits and fires!  

_Enter HECTOR, TROILUS, AJAX, AGAMEMNON, ULYSSES, NESTOR, MENELAUS, and
DIOMEDES, with lights_

**AGAMEMNON**  
We go wrong, we go wrong.  

**AJAX**  
No, yonder 'tis;  
There, where we see the lights.  

**HECTOR**  
I trouble you.  

**AJAX**  
No, not a whit.  

**ULYSSES**  
Here comes himself to guide you.  

_Re-enter ACHILLES_

**ACHILLES**  
Welcome, brave Hector; welcome, princes all.  

**AGAMEMNON**  
So now, fair prince of Troy, I bid good night.  
Ajax commands the guard to tend on you.  

**HECTOR**  
Thanks and good night to the Greeks' general.  

**MENELAUS**  
Good night, my lord.  

**HECTOR**  
Good night, sweet lord Menelaus.  

**THERSITES**  
Sweet draught: 'sweet' quoth 'a! sweet sink,  
sweet sewer.  

**ACHILLES**  
Good night and welcome, both at once, to those  
That go or tarry.  

**AGAMEMNON**  
Good night.  

_Exeunt AGAMEMNON and MENELAUS_

**ACHILLES**  
Old Nestor tarries; and you too, Diomed,  
Keep Hector company an hour or two.  

**DIOMEDES**  
I cannot, lord; I have important business,  
The tide whereof is now. Good night, great Hector.  

**HECTOR**  
Give me your hand.  

**ULYSSES**  
_[Aside to TROILUS]_  
Follow his torch; he goes to  
Calchas' tent:  
I'll keep you company.  

**TROILUS**  
Sweet sir, you honour me.  

**HECTOR**  
And so, good night.  

_Exit DIOMEDES; ULYSSES and TROILUS following_

**ACHILLES**  
Come, come, enter my tent.  

_Exeunt ACHILLES, HECTOR, AJAX, and NESTOR_

**THERSITES**  
That same Diomed's a false-hearted rogue, a most  
unjust knave; I will no more trust him when he leers  
than I will a serpent when he hisses: he will spend  
his mouth, and promise, like Brabbler the hound:  
but when he performs, astronomers foretell it; it  
is prodigious, there will come some change; the sun  
borrows of the moon, when Diomed keeps his  
word. I will rather leave to see Hector, than  
not to dog him: they say he keeps a Trojan  
drab, and uses the traitor Calchas' tent: I'll  
after. Nothing but lechery! all incontinent varlets!  

_Exit_

### SCENE II. The same. Before Calchas' tent.

_Enter DIOMEDES_

**DIOMEDES**  
What, are you up here, ho? speak.  

**CALCHAS**  
_[Within]_  
Who calls?  

**DIOMEDES**  
Calchas, I think. Where's your daughter?  

**CALCHAS**  
_[Within]_  
She comes to you.  

_Enter TROILUS and ULYSSES, at a distance; after them, THERSITES_

**ULYSSES**  
Stand where the torch may not discover us.  

_Enter CRESSIDA_

**TROILUS**  
Cressid comes forth to him.  

**DIOMEDES**  
How now, my charge!  

**CRESSIDA**  
Now, my sweet guardian! Hark, a word with you.  

_Whispers_

**TROILUS**  
Yea, so familiar!  

**ULYSSES**  
She will sing any man at first sight.  

**THERSITES**  
And any man may sing her, if he can take her cliff;  
she's noted.  

**DIOMEDES**  
Will you remember?  

**CRESSIDA**  
Remember! yes.  

**DIOMEDES**  
Nay, but do, then;  
And let your mind be coupled with your words.  

**TROILUS**  
What should she remember?  

**ULYSSES**  
List.  

**CRESSIDA**  
Sweet honey Greek, tempt me no more to folly.  

**THERSITES**  
Roguery!  

**DIOMEDES**  
Nay, then,--  

**CRESSIDA**  
I'll tell you what,--  

**DIOMEDES**  
Foh, foh! come, tell a pin: you are forsworn.  

**CRESSIDA**  
In faith, I cannot: what would you have me do?  

**THERSITES**  
A juggling trick,--to be secretly open.  

**DIOMEDES**  
What did you swear you would bestow on me?  

**CRESSIDA**  
I prithee, do not hold me to mine oath;  
Bid me do any thing but that, sweet Greek.  

**DIOMEDES**  
Good night.  

**TROILUS**  
Hold, patience!  

**ULYSSES**  
How now, Trojan!  

**CRESSIDA**  
Diomed,--  

**DIOMEDES**  
No, no, good night: I'll be your fool no more.  

**TROILUS**  
Thy better must.  

**CRESSIDA**  
Hark, one word in your ear.  

**TROILUS**  
O plague and madness!  

**ULYSSES**  
You are moved, prince; let us depart, I pray you,  
Lest your displeasure should enlarge itself  
To wrathful terms: this place is dangerous;  
The time right deadly; I beseech you, go.  

**TROILUS**  
Behold, I pray you!  

**ULYSSES**  
Nay, good my lord, go off:  
You flow to great distraction; come, my lord.  

**TROILUS**  
I pray thee, stay.  

**ULYSSES**  
You have not patience; come.  

**TROILUS**  
I pray you, stay; by hell and all hell's torments  
I will not speak a word!  

**DIOMEDES**  
And so, good night.  

**CRESSIDA**  
Nay, but you part in anger.  

**TROILUS**  
Doth that grieve thee?  
O wither'd truth!  

**ULYSSES**  
Why, how now, lord!  

**TROILUS**  
By Jove,  
I will be patient.  

**CRESSIDA**  
Guardian!--why, Greek!  

**DIOMEDES**  
Foh, foh! adieu; you palter.  

**CRESSIDA**  
In faith, I do not: come hither once again.  

**ULYSSES**  
You shake, my lord, at something: will you go?  
You will break out.  

**TROILUS**  
She strokes his cheek!  

**ULYSSES**  
Come, come.  

**TROILUS**  
Nay, stay; by Jove, I will not speak a word:  
There is between my will and all offences  
A guard of patience: stay a little while.  

**THERSITES**  
How the devil Luxury, with his fat rump and  
potato-finger, tickles these together! Fry, lechery, fry!  

**DIOMEDES**  
But will you, then?  

**CRESSIDA**  
In faith, I will, la; never trust me else.  

**DIOMEDES**  
Give me some token for the surety of it.  

**CRESSIDA**  
I'll fetch you one.  

_Exit_

**ULYSSES**  
You have sworn patience.  

**TROILUS**  
Fear me not, sweet lord;  
I will not be myself, nor have cognition  
Of what I feel: I am all patience.  

_Re-enter CRESSIDA_

**THERSITES**  
Now the pledge; now, now, now!  

**CRESSIDA**  
Here, Diomed, keep this sleeve.  

**TROILUS**  
O beauty! where is thy faith?  

**ULYSSES**  
My lord,--  

**TROILUS**  
I will be patient; outwardly I will.  

**CRESSIDA**  
You look upon that sleeve; behold it well.  
He loved me--O false wench!--Give't me again.  

**DIOMEDES**  
Whose was't?  

**CRESSIDA**  
It is no matter, now I have't again.  
I will not meet with you to-morrow night:  
I prithee, Diomed, visit me no more.  

**THERSITES**  
Now she sharpens: well said, whetstone!  

**DIOMEDES**  
I shall have it.  

**CRESSIDA**  
What, this?  

**DIOMEDES**  
Ay, that.  

**CRESSIDA**  
O, all you gods! O pretty, pretty pledge!  
Thy master now lies thinking in his bed  
Of thee and me, and sighs, and takes my glove,  
And gives memorial dainty kisses to it,  
As I kiss thee. Nay, do not snatch it from me;  
He that takes that doth take my heart withal.  

**DIOMEDES**  
I had your heart before, this follows it.  

**TROILUS**  
I did swear patience.  

**CRESSIDA**  
You shall not have it, Diomed; faith, you shall not;  
I'll give you something else.  

**DIOMEDES**  
I will have this: whose was it?  

**CRESSIDA**  
It is no matter.  

**DIOMEDES**  
Come, tell me whose it was.  

**CRESSIDA**  
'Twas one's that loved me better than you will.  
But, now you have it, take it.  

**DIOMEDES**  
Whose was it?  

**CRESSIDA**  
By all Diana's waiting-women yond,  
And by herself, I will not tell you whose.  

**DIOMEDES**  
To-morrow will I wear it on my helm,  
And grieve his spirit that dares not challenge it.  

**TROILUS**  
Wert thou the devil, and worest it on thy horn,  
It should be challenged.  

**CRESSIDA**  
Well, well, 'tis done, 'tis past: and yet it is not;  
I will not keep my word.  

**DIOMEDES**  
Why, then, farewell;  
Thou never shalt mock Diomed again.  

**CRESSIDA**  
You shall not go: one cannot speak a word,  
But it straight starts you.  

**DIOMEDES**  
I do not like this fooling.  

**THERSITES**  
Nor I, by Pluto: but that that likes not you pleases me best.  

**DIOMEDES**  
What, shall I come? the hour?  

**CRESSIDA**  
Ay, come:--O Jove!--do come:--I shall be plagued.  

**DIOMEDES**  
Farewell till then.  

**CRESSIDA**  
Good night: I prithee, come.  

_Exit DIOMEDES_

Troilus, farewell! one eye yet looks on thee  
But with my heart the other eye doth see.  
Ah, poor our sex! this fault in us I find,  
The error of our eye directs our mind:  
What error leads must err; O, then conclude  
Minds sway'd by eyes are full of turpitude.  

_Exit_

**THERSITES**  
A proof of strength she could not publish more,  
Unless she said ' My mind is now turn'd whore.'  

**ULYSSES**  
All's done, my lord.  

**TROILUS**  
It is.  

**ULYSSES**  
Why stay we, then?  

**TROILUS**  
To make a recordation to my soul  
Of every syllable that here was spoke.  
But if I tell how these two did co-act,  
Shall I not lie in publishing a truth?  
Sith yet there is a credence in my heart,  
An esperance so obstinately strong,  
That doth invert the attest of eyes and ears,  
As if those organs had deceptious functions,  
Created only to calumniate.  
Was Cressid here?  

**ULYSSES**  
I cannot conjure, Trojan.  

**TROILUS**  
She was not, sure.  

**ULYSSES**  
Most sure she was.  

**TROILUS**  
Why, my negation hath no taste of madness.  

**ULYSSES**  
Nor mine, my lord: Cressid was here but now.  

**TROILUS**  
Let it not be believed for womanhood!  
Think, we had mothers; do not give advantage  
To stubborn critics, apt, without a theme,  
For depravation, to square the general sex  
By Cressid's rule: rather think this not Cressid.  

**ULYSSES**  
What hath she done, prince, that can soil our mothers?  

**TROILUS**  
Nothing at all, unless that this were she.  

**THERSITES**  
Will he swagger himself out on's own eyes?  

**TROILUS**  
This she? no, this is Diomed's Cressida:  
If beauty have a soul, this is not she;  
If souls guide vows, if vows be sanctimonies,  
If sanctimony be the gods' delight,  
If there be rule in unity itself,  
This is not she. O madness of discourse,  
That cause sets up with and against itself!  
Bi-fold authority! where reason can revolt  
Without perdition, and loss assume all reason  
Without revolt: this is, and is not, Cressid.  
Within my soul there doth conduce a fight  
Of this strange nature that a thing inseparate  
Divides more wider than the sky and earth,  
And yet the spacious breadth of this division  
Admits no orifex for a point as subtle  
As Ariachne's broken woof to enter.  
Instance, O instance! strong as Pluto's gates;  
Cressid is mine, tied with the bonds of heaven:  
Instance, O instance! strong as heaven itself;  
The bonds of heaven are slipp'd, dissolved, and loosed;  
And with another knot, five-finger-tied,  
The fractions of her faith, orts of her love,  
The fragments, scraps, the bits and greasy relics  
Of her o'er-eaten faith, are bound to Diomed.  

**ULYSSES**  
May worthy Troilus be half attach'd  
With that which here his passion doth express?  

**TROILUS**  
Ay, Greek; and that shall be divulged well  
In characters as red as Mars his heart  
Inflamed with Venus: never did young man fancy  
With so eternal and so fix'd a soul.  
Hark, Greek: as much as I do Cressid love,  
So much by weight hate I her Diomed:  
That sleeve is mine that he'll bear on his helm;  
Were it a casque composed by Vulcan's skill,  
My sword should bite it: not the dreadful spout  
Which shipmen do the hurricano call,  
Constringed in mass by the almighty sun,  
Shall dizzy with more clamour Neptune's ear  
In his descent than shall my prompted sword  
Falling on Diomed.  

**THERSITES**  
He'll tickle it for his concupy.  

**TROILUS**  
O Cressid! O false Cressid! false, false, false!  
Let all untruths stand by thy stained name,  
And they'll seem glorious.  

**ULYSSES**  
O, contain yourself  
Your passion draws ears hither.  

_Enter AENEAS_

**AENEAS**  
I have been seeking you this hour, my lord:  
Hector, by this, is arming him in Troy;  
Ajax, your guard, stays to conduct you home.  

**TROILUS**  
Have with you, prince. My courteous lord, adieu.  
Farewell, revolted fair! and, Diomed,  
Stand fast, and wear a castle on thy head!  

**ULYSSES**  
I'll bring you to the gates.  

**TROILUS**  
Accept distracted thanks.  

_Exeunt TROILUS, AENEAS, and ULYSSES_

**THERSITES**  
Would I could meet that rogue Diomed! I would  
croak like a raven; I would bode, I would bode.  
Patroclus will give me any thing for the  
intelligence of this whore: the parrot will not  
do more for an almond than he for a commodious drab.  
Lechery, lechery; still, wars and lechery; nothing  
else holds fashion: a burning devil take them!  

_Exit_

### SCENE III. Troy. Before Priam's palace.

_Enter HECTOR and ANDROMACHE_

**ANDROMACHE**  
When was my lord so much ungently temper'd,  
To stop his ears against admonishment?  
Unarm, unarm, and do not fight to-day.  

**HECTOR**  
You train me to offend you; get you in:  
By all the everlasting gods, I'll go!  

**ANDROMACHE**  
My dreams will, sure, prove ominous to the day.  

**HECTOR**  
No more, I say.  

_Enter CASSANDRA_

**CASSANDRA**  
Where is my brother Hector?  

**ANDROMACHE**  
Here, sister; arm'd, and bloody in intent.  
Consort with me in loud and dear petition,  
Pursue we him on knees; for I have dream'd  
Of bloody turbulence, and this whole night  
Hath nothing been but shapes and forms of slaughter.  

**CASSANDRA**  
O, 'tis true.  

**HECTOR**  
Ho! bid my trumpet sound!  

**CASSANDRA**  
No notes of sally, for the heavens, sweet brother.  

**HECTOR**  
Be gone, I say: the gods have heard me swear.  

**CASSANDRA**  
The gods are deaf to hot and peevish vows:  
They are polluted offerings, more abhorr'd  
Than spotted livers in the sacrifice.  

**ANDROMACHE**  
O, be persuaded! do not count it holy  
To hurt by being just: it is as lawful,  
For we would give much, to use violent thefts,  
And rob in the behalf of charity.  

**CASSANDRA**  
It is the purpose that makes strong the vow;  
But vows to every purpose must not hold:  
Unarm, sweet Hector.  

**HECTOR**  
Hold you still, I say;  
Mine honour keeps the weather of my fate:  
Lie every man holds dear; but the brave man  
Holds honour far more precious-dear than life.  

_Enter TROILUS_

How now, young man! mean'st thou to fight to-day?  

**ANDROMACHE**  
Cassandra, call my father to persuade.  

_Exit CASSANDRA_

**HECTOR**  
No, faith, young Troilus; doff thy harness, youth;  
I am to-day i' the vein of chivalry:  
Let grow thy sinews till their knots be strong,  
And tempt not yet the brushes of the war.  
Unarm thee, go, and doubt thou not, brave boy,  
I'll stand to-day for thee and me and Troy.  

**TROILUS**  
Brother, you have a vice of mercy in you,  
Which better fits a lion than a man.  

**HECTOR**  
What vice is that, good Troilus? chide me for it.  

**TROILUS**  
When many times the captive Grecian falls,  
Even in the fan and wind of your fair sword,  
You bid them rise, and live.  

**HECTOR**  
O,'tis fair play.  

**TROILUS**  
Fool's play, by heaven, Hector.  

**HECTOR**  
How now! how now!  

**TROILUS**  
For the love of all the gods,  
Let's leave the hermit pity with our mothers,  
And when we have our armours buckled on,  
The venom'd vengeance ride upon our swords,  
Spur them to ruthful work, rein them from ruth.  

**HECTOR**  
Fie, savage, fie!  

**TROILUS**  
Hector, then 'tis wars.  

**HECTOR**  
Troilus, I would not have you fight to-day.  

**TROILUS**  
Who should withhold me?  
Not fate, obedience, nor the hand of Mars  
Beckoning with fiery truncheon my retire;  
Not Priamus and Hecuba on knees,  
Their eyes o'ergalled with recourse of tears;  
Not you, my brother, with your true sword drawn,  
Opposed to hinder me, should stop my way,  
But by my ruin.  

_Re-enter CASSANDRA, with PRIAM_

**CASSANDRA**  
Lay hold upon him, Priam, hold him fast:  
He is thy crutch; now if thou lose thy stay,  
Thou on him leaning, and all Troy on thee,  
Fall all together.  

**PRIAM**  
Come, Hector, come, go back:  
Thy wife hath dream'd; thy mother hath had visions;  
Cassandra doth foresee; and I myself  
Am like a prophet suddenly enrapt  
To tell thee that this day is ominous:  
Therefore, come back.  

**HECTOR**  
AEneas is a-field;  
And I do stand engaged to many Greeks,  
Even in the faith of valour, to appear  
This morning to them.  

**PRIAM**  
Ay, but thou shalt not go.  

**HECTOR**  
I must not break my faith.  
You know me dutiful; therefore, dear sir,  
Let me not shame respect; but give me leave  
To take that course by your consent and voice,  
Which you do here forbid me, royal Priam.  

**CASSANDRA**  
O Priam, yield not to him!  

**ANDROMACHE**  
Do not, dear father.  

**HECTOR**  
Andromache, I am offended with you:  
Upon the love you bear me, get you in.  

_Exit ANDROMACHE_

**TROILUS**  
This foolish, dreaming, superstitious girl  
Makes all these bodements.  

**CASSANDRA**  
O, farewell, dear Hector!  
Look, how thou diest! look, how thy eye turns pale!  
Look, how thy wounds do bleed at many vents!  
Hark, how Troy roars! how Hecuba cries out!  
How poor Andromache shrills her dolours forth!  
Behold, distraction, frenzy and amazement,  
Like witless antics, one another meet,  
And all cry, Hector! Hector's dead! O Hector!  

**TROILUS**  
Away! away!  

**CASSANDRA**  
Farewell: yet, soft! Hector! take my leave:  
Thou dost thyself and all our Troy deceive.  

_Exit_

**HECTOR**  
You are amazed, my liege, at her exclaim:  
Go in and cheer the town: we'll forth and fight,  
Do deeds worth praise and tell you them at night.  

**PRIAM**  
Farewell: the gods with safety stand about thee!  

_Exeunt severally PRIAM and HECTOR. Alarums_

**TROILUS**  
They are at it, hark! Proud Diomed, believe,  
I come to lose my arm, or win my sleeve.  

_Enter PANDARUS_

**PANDARUS**  
Do you hear, my lord? do you hear?  

**TROILUS**  
What now?  

**PANDARUS**  
Here's a letter come from yond poor girl.  

**TROILUS**  
Let me read.  

**PANDARUS**  
A whoreson tisick, a whoreson rascally tisick so  
troubles me, and the foolish fortune of this girl;  
and what one thing, what another, that I shall  
leave you one o' these days: and I have a rheum  
in mine eyes too, and such an ache in my bones  
that, unless a man were cursed, I cannot tell what  
to think on't. What says she there?  

**TROILUS**  
Words, words, mere words, no matter from the heart:  
The effect doth operate another way.  

_Tearing the letter_

Go, wind, to wind, there turn and change together.  
My love with words and errors still she feeds;  
But edifies another with her deeds.  

_Exeunt severally_

### SCENE IV. Plains between Troy and the Grecian camp.

_Alarums: excursions. Enter THERSITES_

**THERSITES**  
Now they are clapper-clawing one another; I'll go  
look on. That dissembling abominable varlets Diomed,  
has got that same scurvy doting foolish young knave's  
sleeve of Troy there in his helm: I would fain see  
them meet; that that same young Trojan ass, that  
loves the whore there, might send that Greekish  
whore-masterly villain, with the sleeve, back to the  
dissembling luxurious drab, of a sleeveless errand.  
O' the t'other side, the policy of those crafty  
swearing rascals, that stale old mouse-eaten dry  
cheese, Nestor, and that same dog-fox, Ulysses, is  
not proved worthy a blackberry: they set me up, in  
policy, that mongrel cur, Ajax, against that dog of  
as bad a kind, Achilles: and now is the cur Ajax  
prouder than the cur Achilles, and will not arm  
to-day; whereupon the Grecians begin to proclaim  
barbarism, and policy grows into an ill opinion.  
Soft! here comes sleeve, and t'other.  

_Enter DIOMEDES, TROILUS following_

**TROILUS**  
Fly not; for shouldst thou take the river Styx,  
I would swim after.  

**DIOMEDES**  
Thou dost miscall retire:  
I do not fly, but advantageous care  
Withdrew me from the odds of multitude:  
Have at thee!  

**THERSITES**  
Hold thy whore, Grecian!--now for thy whore,  
Trojan!--now the sleeve, now the sleeve!  

_Exeunt TROILUS and DIOMEDES, fighting_

_Enter HECTOR_

**HECTOR**  
What art thou, Greek? art thou for Hector's match?  
Art thou of blood and honour?  

**THERSITES**  
No, no, I am a rascal; a scurvy railing knave:  
a very filthy rogue.  

**HECTOR**  
I do believe thee: live.  

_Exit_

**THERSITES**  
God-a-mercy, that thou wilt believe me; but a  
plague break thy neck for frightening me! What's  
become of the wenching rogues? I think they have  
swallowed one another: I would laugh at that  
miracle: yet, in a sort, lechery eats itself.  
I'll seek them.  

_Exit_

### SCENE V. Another part of the plains.

_Enter DIOMEDES and a Servant_

**DIOMEDES**  
Go, go, my servant, take thou Troilus' horse;  
Present the fair steed to my lady Cressid:  
Fellow, commend my service to her beauty;  
Tell her I have chastised the amorous Trojan,  
And am her knight by proof.  

**Servant**  
I go, my lord.  

_Exit_

_Enter AGAMEMNON_

**AGAMEMNON**  
Renew, renew! The fierce Polydamas  
Hath beat down Menon: bastard Margarelon  
Hath Doreus prisoner,  
And stands colossus-wise, waving his beam,  
Upon the pashed corses of the kings  
Epistrophus and Cedius: Polyxenes is slain,  
Amphimachus and Thoas deadly hurt,  
Patroclus ta'en or slain, and Palamedes  
Sore hurt and bruised: the dreadful Sagittary  
Appals our numbers: haste we, Diomed,  
To reinforcement, or we perish all.  

_Enter NESTOR_

**NESTOR**  
Go, bear Patroclus' body to Achilles;  
And bid the snail-paced Ajax arm for shame.  
There is a thousand Hectors in the field:  
Now here he fights on Galathe his horse,  
And there lacks work; anon he's there afoot,  
And there they fly or die, like scaled sculls  
Before the belching whale; then is he yonder,  
And there the strawy Greeks, ripe for his edge,  
Fall down before him, like the mower's swath:  
Here, there, and every where, he leaves and takes,  
Dexterity so obeying appetite  
That what he will he does, and does so much  
That proof is call'd impossibility.  

_Enter ULYSSES_

**ULYSSES**  
O, courage, courage, princes! great Achilles  
Is arming, weeping, cursing, vowing vengeance:  
Patroclus' wounds have roused his drowsy blood,  
Together with his mangled Myrmidons,  
That noseless, handless, hack'd and chipp'd, come to him,  
Crying on Hector. Ajax hath lost a friend  
And foams at mouth, and he is arm'd and at it,  
Roaring for Troilus, who hath done to-day  
Mad and fantastic execution,  
Engaging and redeeming of himself  
With such a careless force and forceless care  
As if that luck, in very spite of cunning,  
Bade him win all.  

_Enter AJAX_

**AJAX**  
Troilus! thou coward Troilus!  

_Exit_

**DIOMEDES**  
Ay, there, there.  

**NESTOR**  
So, so, we draw together.  

_Enter ACHILLES_

**ACHILLES**  
Where is this Hector?  
Come, come, thou boy-queller, show thy face;  
Know what it is to meet Achilles angry:  
Hector? where's Hector? I will none but Hector.  

_Exeunt_

### SCENE VI. Another part of the plains.

_Enter AJAX_

**AJAX**  
Troilus, thou coward Troilus, show thy head!  

_Enter DIOMEDES_

**DIOMEDES**  
Troilus, I say! where's Troilus?  

**AJAX**  
What wouldst thou?  

**DIOMEDES**  
I would correct him.  

**AJAX**  
Were I the general, thou shouldst have my office  
Ere that correction. Troilus, I say! what, Troilus!  

_Enter TROILUS_

**TROILUS**  
O traitor Diomed! turn thy false face, thou traitor,  
And pay thy life thou owest me for my horse!  

**DIOMEDES**  
Ha, art thou there?  

**AJAX**  
I'll fight with him alone: stand, Diomed.  

**DIOMEDES**  
He is my prize; I will not look upon.  

**TROILUS**  
Come, both you cogging Greeks; have at you both!  

_Exeunt, fighting_

_Enter HECTOR_

**HECTOR**  
Yea, Troilus? O, well fought, my youngest brother!  

_Enter ACHILLES_

**ACHILLES**  
Now do I see thee, ha! have at thee, Hector!  

**HECTOR**  
Pause, if thou wilt.  

**ACHILLES**  
I do disdain thy courtesy, proud Trojan:  
Be happy that my arms are out of use:  
My rest and negligence befriends thee now,  
But thou anon shalt hear of me again;  
Till when, go seek thy fortune.  

_Exit_

**HECTOR**  
Fare thee well:  
I would have been much more a fresher man,  
Had I expected thee. How now, my brother!  

_Re-enter TROILUS_

**TROILUS**  
Ajax hath ta'en AEneas: shall it be?  
No, by the flame of yonder glorious heaven,  
He shall not carry him: I'll be ta'en too,  
Or bring him off: fate, hear me what I say!  
I reck not though I end my life to-day.  

_Exit_

_Enter one in sumptuous armour_

**HECTOR**  
Stand, stand, thou Greek; thou art a goodly mark:  
No? wilt thou not? I like thy armour well;  
I'll frush it and unlock the rivets all,  
But I'll be master of it: wilt thou not,  
beast, abide?  
Why, then fly on, I'll hunt thee for thy hide.  

_Exeunt_

### SCENE VII. Another part of the plains.

_Enter ACHILLES, with Myrmidons_

**ACHILLES**  
Come here about me, you my Myrmidons;  
Mark what I say. Attend me where I wheel:  
Strike not a stroke, but keep yourselves in breath:  
And when I have the bloody Hector found,  
Empale him with your weapons round about;  
In fellest manner execute your aims.  
Follow me, sirs, and my proceedings eye:  
It is decreed Hector the great must die.  

_Exeunt_

_Enter MENELAUS and PARIS, fighting: then THERSITES_

**THERSITES**  
The cuckold and the cuckold-maker are at it. Now,  
bull! now, dog! 'Loo, Paris, 'loo! now my double-  
henned sparrow! 'loo, Paris, 'loo! The bull has the  
game: ware horns, ho!  

_Exeunt PARIS and MENELAUS_

_Enter MARGARELON_

**MARGARELON**  
Turn, slave, and fight.  

**THERSITES**  
What art thou?  

**MARGARELON**  
A bastard son of Priam's.  

**THERSITES**  
I am a bastard too; I love bastards: I am a bastard  
begot, bastard instructed, bastard in mind, bastard  
in valour, in every thing illegitimate. One bear will  
not bite another, and wherefore should one bastard?  
Take heed, the quarrel's most ominous to us: if the  
son of a whore fight for a whore, he tempts judgment:  
farewell, bastard.  

_Exit_

**MARGARELON**  
The devil take thee, coward!  

_Exit_

### SCENE VIII. Another part of the plains.

_Enter HECTOR_

**HECTOR**  
Most putrefied core, so fair without,  
Thy goodly armour thus hath cost thy life.  
Now is my day's work done; I'll take good breath:  
Rest, sword; thou hast thy fill of blood and death.  

_Puts off his helmet and hangs his shield behind him_

_Enter ACHILLES and Myrmidons_

**ACHILLES**  
Look, Hector, how the sun begins to set;  
How ugly night comes breathing at his heels:  
Even with the vail and darking of the sun,  
To close the day up, Hector's life is done.  

**HECTOR**  
I am unarm'd; forego this vantage, Greek.  

**ACHILLES**  
Strike, fellows, strike; this is the man I seek.  

_HECTOR falls_

So, Ilion, fall thou next! now, Troy, sink down!  
Here lies thy heart, thy sinews, and thy bone.  
On, Myrmidons, and cry you all amain,  
'Achilles hath the mighty Hector slain.'  

_A retreat sounded_

Hark! a retire upon our Grecian part.  

**MYRMIDONS**  
The Trojan trumpets sound the like, my lord.  

**ACHILLES**  
The dragon wing of night o'erspreads the earth,  
And, stickler-like, the armies separates.  
My half-supp'd sword, that frankly would have fed,  
Pleased with this dainty bait, thus goes to bed.  

_Sheathes his sword_

Come, tie his body to my horse's tail;  
Along the field I will the Trojan trail.  

_Exeunt_

### SCENE IX. Another part of the plains.

_Enter AGAMEMNON, AJAX, MENELAUS, NESTOR, DIOMEDES, and others, marching.
Shouts within_

**AGAMEMNON**  
Hark! hark! what shout is that?  

**NESTOR**  
Peace, drums!  

_Within_

Achilles! Achilles! Hector's slain! Achilles.  

**DIOMEDES**  
The bruit is, Hector's slain, and by Achilles.  

**AJAX**  
If it be so, yet bragless let it be;  
Great Hector was a man as good as he.  

**AGAMEMNON**  
March patiently along: let one be sent  
To pray Achilles see us at our tent.  
If in his death the gods have us befriended,  
Great Troy is ours, and our sharp wars are ended.  

_Exeunt, marching_

### SCENE X. Another part of the plains.

_Enter AENEAS and Trojans_

**AENEAS**  
Stand, ho! yet are we masters of the field:  
Never go home; here starve we out the night.  

_Enter TROILUS_

**TROILUS**  
Hector is slain.  

**ALL**  
Hector! the gods forbid!  

**TROILUS**  
He's dead; and at the murderer's horse's tail,  
In beastly sort, dragg'd through the shameful field.  
Frown on, you heavens, effect your rage with speed!  
Sit, gods, upon your thrones, and smile at Troy!  
I say, at once let your brief plagues be mercy,  
And linger not our sure destructions on!  

**AENEAS**  
My lord, you do discomfort all the host!  

**TROILUS**  
You understand me not that tell me so:  
I do not speak of flight, of fear, of death,  
But dare all imminence that gods and men  
Address their dangers in. Hector is gone:  
Who shall tell Priam so, or Hecuba?  
Let him that will a screech-owl aye be call'd,  
Go in to Troy, and say there, Hector's dead:  
There is a word will Priam turn to stone;  
Make wells and Niobes of the maids and wives,  
Cold statues of the youth, and, in a word,  
Scare Troy out of itself. But, march away:  
Hector is dead; there is no more to say.  
Stay yet. You vile abominable tents,  
Thus proudly pight upon our Phrygian plains,  
Let Titan rise as early as he dare,  
I'll through and through you! and, thou great-sized coward,  
No space of earth shall sunder our two hates:  
I'll haunt thee like a wicked conscience still,  
That mouldeth goblins swift as frenzy's thoughts.  
Strike a free march to Troy! with comfort go:  
Hope of revenge shall hide our inward woe.  

_Exeunt AENEAS and Trojans_

_As TROILUS is going out, enter, from the other side, PANDARUS_

**PANDARUS**  
But hear you, hear you!  

**TROILUS**  
Hence, broker-lackey! ignomy and shame  
Pursue thy life, and live aye with thy name!  

_Exit_

**PANDARUS**  
A goodly medicine for my aching bones! O world!  
world! world! thus is the poor agent despised!  
O traitors and bawds, how earnestly are you set  
a-work, and how ill requited! why should our  
endeavour be so loved and the performance so loathed?  
what verse for it? what instance for it? Let me see:  
Full merrily the humble-bee doth sing,  
Till he hath lost his honey and his sting;  
And being once subdued in armed tail,  
Sweet honey and sweet notes together fail.  
Good traders in the flesh, set this in your  
painted cloths.  
As many as be here of pander's hall,  
Your eyes, half out, weep out at Pandar's fall;  
Or if you cannot weep, yet give some groans,  
Though not for me, yet for your aching bones.  
Brethren and sisters of the hold-door trade,  
Some two months hence my will shall here be made:  
It should be now, but that my fear is this,  
Some galled goose of Winchester would hiss:  
Till then I'll sweat and seek about for eases,  
And at that time bequeathe you my diseases.  

_Exit_
